# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for /usr/include/GL/gl.h
from OpenGL import platform
from OpenGL.constants import *
from OpenGL.constant import Constant
from OpenGL.arrays.arraydatatype import *
from ctypes import *
c_void = None


GL_VERSION_1_1=Constant( 'GL_VERSION_1_1', 1 )
GL_CURRENT_BIT=Constant( 'GL_CURRENT_BIT', 1 )
GL_POINT_BIT=Constant( 'GL_POINT_BIT', 2 )
GL_LINE_BIT=Constant( 'GL_LINE_BIT', 4 )
GL_POLYGON_BIT=Constant( 'GL_POLYGON_BIT', 8 )
GL_POLYGON_STIPPLE_BIT=Constant( 'GL_POLYGON_STIPPLE_BIT', 16 )
GL_PIXEL_MODE_BIT=Constant( 'GL_PIXEL_MODE_BIT', 32 )
GL_LIGHTING_BIT=Constant( 'GL_LIGHTING_BIT', 64 )
GL_FOG_BIT=Constant( 'GL_FOG_BIT', 128 )
GL_DEPTH_BUFFER_BIT=Constant( 'GL_DEPTH_BUFFER_BIT', 256 )
GL_ACCUM_BUFFER_BIT=Constant( 'GL_ACCUM_BUFFER_BIT', 512 )
GL_STENCIL_BUFFER_BIT=Constant( 'GL_STENCIL_BUFFER_BIT', 1024 )
GL_VIEWPORT_BIT=Constant( 'GL_VIEWPORT_BIT', 2048 )
GL_TRANSFORM_BIT=Constant( 'GL_TRANSFORM_BIT', 4096 )
GL_ENABLE_BIT=Constant( 'GL_ENABLE_BIT', 8192 )
GL_COLOR_BUFFER_BIT=Constant( 'GL_COLOR_BUFFER_BIT', 16384 )
GL_HINT_BIT=Constant( 'GL_HINT_BIT', 32768 )
GL_EVAL_BIT=Constant( 'GL_EVAL_BIT', 65536 )
GL_LIST_BIT=Constant( 'GL_LIST_BIT', 131072 )
GL_TEXTURE_BIT=Constant( 'GL_TEXTURE_BIT', 262144 )
GL_SCISSOR_BIT=Constant( 'GL_SCISSOR_BIT', 524288 )
GL_ALL_ATTRIB_BITS=Constant( 'GL_ALL_ATTRIB_BITS', 4294967295 )
GL_CLIENT_PIXEL_STORE_BIT=Constant( 'GL_CLIENT_PIXEL_STORE_BIT', 1 )
GL_CLIENT_VERTEX_ARRAY_BIT=Constant( 'GL_CLIENT_VERTEX_ARRAY_BIT', 2 )
GL_CLIENT_ALL_ATTRIB_BITS=Constant( 'GL_CLIENT_ALL_ATTRIB_BITS', 4294967295 )
GL_FALSE=Constant( 'GL_FALSE', 0 )
GL_TRUE=Constant( 'GL_TRUE', 1 )
GL_POINTS=Constant( 'GL_POINTS', 0 )
GL_LINES=Constant( 'GL_LINES', 1 )
GL_LINE_LOOP=Constant( 'GL_LINE_LOOP', 2 )
GL_LINE_STRIP=Constant( 'GL_LINE_STRIP', 3 )
GL_TRIANGLES=Constant( 'GL_TRIANGLES', 4 )
GL_TRIANGLE_STRIP=Constant( 'GL_TRIANGLE_STRIP', 5 )
GL_TRIANGLE_FAN=Constant( 'GL_TRIANGLE_FAN', 6 )
GL_QUADS=Constant( 'GL_QUADS', 7 )
GL_QUAD_STRIP=Constant( 'GL_QUAD_STRIP', 8 )
GL_POLYGON=Constant( 'GL_POLYGON', 9 )
GL_ACCUM=Constant( 'GL_ACCUM', 256 )
GL_LOAD=Constant( 'GL_LOAD', 257 )
GL_RETURN=Constant( 'GL_RETURN', 258 )
GL_MULT=Constant( 'GL_MULT', 259 )
GL_ADD=Constant( 'GL_ADD', 260 )
GL_NEVER=Constant( 'GL_NEVER', 512 )
GL_LESS=Constant( 'GL_LESS', 513 )
GL_EQUAL=Constant( 'GL_EQUAL', 514 )
GL_LEQUAL=Constant( 'GL_LEQUAL', 515 )
GL_GREATER=Constant( 'GL_GREATER', 516 )
GL_NOTEQUAL=Constant( 'GL_NOTEQUAL', 517 )
GL_GEQUAL=Constant( 'GL_GEQUAL', 518 )
GL_ALWAYS=Constant( 'GL_ALWAYS', 519 )
GL_ZERO=Constant( 'GL_ZERO', 0 )
GL_ONE=Constant( 'GL_ONE', 1 )
GL_SRC_COLOR=Constant( 'GL_SRC_COLOR', 768 )
GL_ONE_MINUS_SRC_COLOR=Constant( 'GL_ONE_MINUS_SRC_COLOR', 769 )
GL_SRC_ALPHA=Constant( 'GL_SRC_ALPHA', 770 )
GL_ONE_MINUS_SRC_ALPHA=Constant( 'GL_ONE_MINUS_SRC_ALPHA', 771 )
GL_DST_ALPHA=Constant( 'GL_DST_ALPHA', 772 )
GL_ONE_MINUS_DST_ALPHA=Constant( 'GL_ONE_MINUS_DST_ALPHA', 773 )
GL_DST_COLOR=Constant( 'GL_DST_COLOR', 774 )
GL_ONE_MINUS_DST_COLOR=Constant( 'GL_ONE_MINUS_DST_COLOR', 775 )
GL_SRC_ALPHA_SATURATE=Constant( 'GL_SRC_ALPHA_SATURATE', 776 )
GL_NONE=Constant( 'GL_NONE', 0 )
GL_FRONT_LEFT=Constant( 'GL_FRONT_LEFT', 1024 )
GL_FRONT_RIGHT=Constant( 'GL_FRONT_RIGHT', 1025 )
GL_BACK_LEFT=Constant( 'GL_BACK_LEFT', 1026 )
GL_BACK_RIGHT=Constant( 'GL_BACK_RIGHT', 1027 )
GL_FRONT=Constant( 'GL_FRONT', 1028 )
GL_BACK=Constant( 'GL_BACK', 1029 )
GL_LEFT=Constant( 'GL_LEFT', 1030 )
GL_RIGHT=Constant( 'GL_RIGHT', 1031 )
GL_FRONT_AND_BACK=Constant( 'GL_FRONT_AND_BACK', 1032 )
GL_AUX0=Constant( 'GL_AUX0', 1033 )
GL_AUX1=Constant( 'GL_AUX1', 1034 )
GL_AUX2=Constant( 'GL_AUX2', 1035 )
GL_AUX3=Constant( 'GL_AUX3', 1036 )
GL_NO_ERROR=Constant( 'GL_NO_ERROR', 0 )
GL_INVALID_ENUM=Constant( 'GL_INVALID_ENUM', 1280 )
GL_INVALID_VALUE=Constant( 'GL_INVALID_VALUE', 1281 )
GL_INVALID_OPERATION=Constant( 'GL_INVALID_OPERATION', 1282 )
GL_STACK_OVERFLOW=Constant( 'GL_STACK_OVERFLOW', 1283 )
GL_STACK_UNDERFLOW=Constant( 'GL_STACK_UNDERFLOW', 1284 )
GL_OUT_OF_MEMORY=Constant( 'GL_OUT_OF_MEMORY', 1285 )
GL_TABLE_TOO_LARGE=Constant( 'GL_TABLE_TOO_LARGE', 32817 )
GL_2D=Constant( 'GL_2D', 1536 )
GL_3D=Constant( 'GL_3D', 1537 )
GL_3D_COLOR=Constant( 'GL_3D_COLOR', 1538 )
GL_3D_COLOR_TEXTURE=Constant( 'GL_3D_COLOR_TEXTURE', 1539 )
GL_4D_COLOR_TEXTURE=Constant( 'GL_4D_COLOR_TEXTURE', 1540 )
GL_PASS_THROUGH_TOKEN=Constant( 'GL_PASS_THROUGH_TOKEN', 1792 )
GL_POINT_TOKEN=Constant( 'GL_POINT_TOKEN', 1793 )
GL_LINE_TOKEN=Constant( 'GL_LINE_TOKEN', 1794 )
GL_POLYGON_TOKEN=Constant( 'GL_POLYGON_TOKEN', 1795 )
GL_BITMAP_TOKEN=Constant( 'GL_BITMAP_TOKEN', 1796 )
GL_DRAW_PIXEL_TOKEN=Constant( 'GL_DRAW_PIXEL_TOKEN', 1797 )
GL_COPY_PIXEL_TOKEN=Constant( 'GL_COPY_PIXEL_TOKEN', 1798 )
GL_LINE_RESET_TOKEN=Constant( 'GL_LINE_RESET_TOKEN', 1799 )
GL_EXP=Constant( 'GL_EXP', 2048 )
GL_EXP2=Constant( 'GL_EXP2', 2049 )
GL_CW=Constant( 'GL_CW', 2304 )
GL_CCW=Constant( 'GL_CCW', 2305 )
GL_COEFF=Constant( 'GL_COEFF', 2560 )
GL_ORDER=Constant( 'GL_ORDER', 2561 )
GL_DOMAIN=Constant( 'GL_DOMAIN', 2562 )
GL_PIXEL_MAP_I_TO_I=Constant( 'GL_PIXEL_MAP_I_TO_I', 3184 )
GL_PIXEL_MAP_S_TO_S=Constant( 'GL_PIXEL_MAP_S_TO_S', 3185 )
GL_PIXEL_MAP_I_TO_R=Constant( 'GL_PIXEL_MAP_I_TO_R', 3186 )
GL_PIXEL_MAP_I_TO_G=Constant( 'GL_PIXEL_MAP_I_TO_G', 3187 )
GL_PIXEL_MAP_I_TO_B=Constant( 'GL_PIXEL_MAP_I_TO_B', 3188 )
GL_PIXEL_MAP_I_TO_A=Constant( 'GL_PIXEL_MAP_I_TO_A', 3189 )
GL_PIXEL_MAP_R_TO_R=Constant( 'GL_PIXEL_MAP_R_TO_R', 3190 )
GL_PIXEL_MAP_G_TO_G=Constant( 'GL_PIXEL_MAP_G_TO_G', 3191 )
GL_PIXEL_MAP_B_TO_B=Constant( 'GL_PIXEL_MAP_B_TO_B', 3192 )
GL_PIXEL_MAP_A_TO_A=Constant( 'GL_PIXEL_MAP_A_TO_A', 3193 )
GL_VERTEX_ARRAY_POINTER=Constant( 'GL_VERTEX_ARRAY_POINTER', 32910 )
GL_NORMAL_ARRAY_POINTER=Constant( 'GL_NORMAL_ARRAY_POINTER', 32911 )
GL_COLOR_ARRAY_POINTER=Constant( 'GL_COLOR_ARRAY_POINTER', 32912 )
GL_INDEX_ARRAY_POINTER=Constant( 'GL_INDEX_ARRAY_POINTER', 32913 )
GL_TEXTURE_COORD_ARRAY_POINTER=Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER', 32914 )
GL_EDGE_FLAG_ARRAY_POINTER=Constant( 'GL_EDGE_FLAG_ARRAY_POINTER', 32915 )
GL_CURRENT_COLOR=Constant( 'GL_CURRENT_COLOR', 2816 )
GL_CURRENT_INDEX=Constant( 'GL_CURRENT_INDEX', 2817 )
GL_CURRENT_NORMAL=Constant( 'GL_CURRENT_NORMAL', 2818 )
GL_CURRENT_TEXTURE_COORDS=Constant( 'GL_CURRENT_TEXTURE_COORDS', 2819 )
GL_CURRENT_RASTER_COLOR=Constant( 'GL_CURRENT_RASTER_COLOR', 2820 )
GL_CURRENT_RASTER_INDEX=Constant( 'GL_CURRENT_RASTER_INDEX', 2821 )
GL_CURRENT_RASTER_TEXTURE_COORDS=Constant( 'GL_CURRENT_RASTER_TEXTURE_COORDS', 2822 )
GL_CURRENT_RASTER_POSITION=Constant( 'GL_CURRENT_RASTER_POSITION', 2823 )
GL_CURRENT_RASTER_POSITION_VALID=Constant( 'GL_CURRENT_RASTER_POSITION_VALID', 2824 )
GL_CURRENT_RASTER_DISTANCE=Constant( 'GL_CURRENT_RASTER_DISTANCE', 2825 )
GL_POINT_SMOOTH=Constant( 'GL_POINT_SMOOTH', 2832 )
GL_POINT_SIZE=Constant( 'GL_POINT_SIZE', 2833 )
GL_SMOOTH_POINT_SIZE_RANGE=Constant( 'GL_SMOOTH_POINT_SIZE_RANGE', 2834 )
GL_SMOOTH_POINT_SIZE_GRANULARITY=Constant( 'GL_SMOOTH_POINT_SIZE_GRANULARITY', 2835 )
GL_POINT_SIZE_RANGE=Constant( 'GL_POINT_SIZE_RANGE', 2834 )
GL_POINT_SIZE_GRANULARITY=Constant( 'GL_POINT_SIZE_GRANULARITY', 2835 )
GL_LINE_SMOOTH=Constant( 'GL_LINE_SMOOTH', 2848 )
GL_LINE_WIDTH=Constant( 'GL_LINE_WIDTH', 2849 )
GL_SMOOTH_LINE_WIDTH_RANGE=Constant( 'GL_SMOOTH_LINE_WIDTH_RANGE', 2850 )
GL_SMOOTH_LINE_WIDTH_GRANULARITY=Constant( 'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 2851 )
GL_LINE_WIDTH_RANGE=Constant( 'GL_LINE_WIDTH_RANGE', 2850 )
GL_LINE_WIDTH_GRANULARITY=Constant( 'GL_LINE_WIDTH_GRANULARITY', 2851 )
GL_LINE_STIPPLE=Constant( 'GL_LINE_STIPPLE', 2852 )
GL_LINE_STIPPLE_PATTERN=Constant( 'GL_LINE_STIPPLE_PATTERN', 2853 )
GL_LINE_STIPPLE_REPEAT=Constant( 'GL_LINE_STIPPLE_REPEAT', 2854 )
GL_LIST_MODE=Constant( 'GL_LIST_MODE', 2864 )
GL_MAX_LIST_NESTING=Constant( 'GL_MAX_LIST_NESTING', 2865 )
GL_LIST_BASE=Constant( 'GL_LIST_BASE', 2866 )
GL_LIST_INDEX=Constant( 'GL_LIST_INDEX', 2867 )
GL_POLYGON_MODE=Constant( 'GL_POLYGON_MODE', 2880 )
GL_POLYGON_SMOOTH=Constant( 'GL_POLYGON_SMOOTH', 2881 )
GL_POLYGON_STIPPLE=Constant( 'GL_POLYGON_STIPPLE', 2882 )
GL_EDGE_FLAG=Constant( 'GL_EDGE_FLAG', 2883 )
GL_CULL_FACE=Constant( 'GL_CULL_FACE', 2884 )
GL_CULL_FACE_MODE=Constant( 'GL_CULL_FACE_MODE', 2885 )
GL_FRONT_FACE=Constant( 'GL_FRONT_FACE', 2886 )
GL_LIGHTING=Constant( 'GL_LIGHTING', 2896 )
GL_LIGHT_MODEL_LOCAL_VIEWER=Constant( 'GL_LIGHT_MODEL_LOCAL_VIEWER', 2897 )
GL_LIGHT_MODEL_TWO_SIDE=Constant( 'GL_LIGHT_MODEL_TWO_SIDE', 2898 )
GL_LIGHT_MODEL_AMBIENT=Constant( 'GL_LIGHT_MODEL_AMBIENT', 2899 )
GL_SHADE_MODEL=Constant( 'GL_SHADE_MODEL', 2900 )
GL_COLOR_MATERIAL_FACE=Constant( 'GL_COLOR_MATERIAL_FACE', 2901 )
GL_COLOR_MATERIAL_PARAMETER=Constant( 'GL_COLOR_MATERIAL_PARAMETER', 2902 )
GL_COLOR_MATERIAL=Constant( 'GL_COLOR_MATERIAL', 2903 )
GL_FOG=Constant( 'GL_FOG', 2912 )
GL_FOG_INDEX=Constant( 'GL_FOG_INDEX', 2913 )
GL_FOG_DENSITY=Constant( 'GL_FOG_DENSITY', 2914 )
GL_FOG_START=Constant( 'GL_FOG_START', 2915 )
GL_FOG_END=Constant( 'GL_FOG_END', 2916 )
GL_FOG_MODE=Constant( 'GL_FOG_MODE', 2917 )
GL_FOG_COLOR=Constant( 'GL_FOG_COLOR', 2918 )
GL_DEPTH_RANGE=Constant( 'GL_DEPTH_RANGE', 2928 )
GL_DEPTH_TEST=Constant( 'GL_DEPTH_TEST', 2929 )
GL_DEPTH_WRITEMASK=Constant( 'GL_DEPTH_WRITEMASK', 2930 )
GL_DEPTH_CLEAR_VALUE=Constant( 'GL_DEPTH_CLEAR_VALUE', 2931 )
GL_DEPTH_FUNC=Constant( 'GL_DEPTH_FUNC', 2932 )
GL_ACCUM_CLEAR_VALUE=Constant( 'GL_ACCUM_CLEAR_VALUE', 2944 )
GL_STENCIL_TEST=Constant( 'GL_STENCIL_TEST', 2960 )
GL_STENCIL_CLEAR_VALUE=Constant( 'GL_STENCIL_CLEAR_VALUE', 2961 )
GL_STENCIL_FUNC=Constant( 'GL_STENCIL_FUNC', 2962 )
GL_STENCIL_VALUE_MASK=Constant( 'GL_STENCIL_VALUE_MASK', 2963 )
GL_STENCIL_FAIL=Constant( 'GL_STENCIL_FAIL', 2964 )
GL_STENCIL_PASS_DEPTH_FAIL=Constant( 'GL_STENCIL_PASS_DEPTH_FAIL', 2965 )
GL_STENCIL_PASS_DEPTH_PASS=Constant( 'GL_STENCIL_PASS_DEPTH_PASS', 2966 )
GL_STENCIL_REF=Constant( 'GL_STENCIL_REF', 2967 )
GL_STENCIL_WRITEMASK=Constant( 'GL_STENCIL_WRITEMASK', 2968 )
GL_MATRIX_MODE=Constant( 'GL_MATRIX_MODE', 2976 )
GL_NORMALIZE=Constant( 'GL_NORMALIZE', 2977 )
GL_VIEWPORT=Constant( 'GL_VIEWPORT', 2978 )
GL_MODELVIEW_STACK_DEPTH=Constant( 'GL_MODELVIEW_STACK_DEPTH', 2979 )
GL_PROJECTION_STACK_DEPTH=Constant( 'GL_PROJECTION_STACK_DEPTH', 2980 )
GL_TEXTURE_STACK_DEPTH=Constant( 'GL_TEXTURE_STACK_DEPTH', 2981 )
GL_MODELVIEW_MATRIX=Constant( 'GL_MODELVIEW_MATRIX', 2982 )
GL_PROJECTION_MATRIX=Constant( 'GL_PROJECTION_MATRIX', 2983 )
GL_TEXTURE_MATRIX=Constant( 'GL_TEXTURE_MATRIX', 2984 )
GL_ATTRIB_STACK_DEPTH=Constant( 'GL_ATTRIB_STACK_DEPTH', 2992 )
GL_CLIENT_ATTRIB_STACK_DEPTH=Constant( 'GL_CLIENT_ATTRIB_STACK_DEPTH', 2993 )
GL_ALPHA_TEST=Constant( 'GL_ALPHA_TEST', 3008 )
GL_ALPHA_TEST_FUNC=Constant( 'GL_ALPHA_TEST_FUNC', 3009 )
GL_ALPHA_TEST_REF=Constant( 'GL_ALPHA_TEST_REF', 3010 )
GL_DITHER=Constant( 'GL_DITHER', 3024 )
GL_BLEND_DST=Constant( 'GL_BLEND_DST', 3040 )
GL_BLEND_SRC=Constant( 'GL_BLEND_SRC', 3041 )
GL_BLEND=Constant( 'GL_BLEND', 3042 )
GL_LOGIC_OP_MODE=Constant( 'GL_LOGIC_OP_MODE', 3056 )
GL_INDEX_LOGIC_OP=Constant( 'GL_INDEX_LOGIC_OP', 3057 )
GL_LOGIC_OP=Constant( 'GL_LOGIC_OP', 3057 )
GL_COLOR_LOGIC_OP=Constant( 'GL_COLOR_LOGIC_OP', 3058 )
GL_AUX_BUFFERS=Constant( 'GL_AUX_BUFFERS', 3072 )
GL_DRAW_BUFFER=Constant( 'GL_DRAW_BUFFER', 3073 )
GL_READ_BUFFER=Constant( 'GL_READ_BUFFER', 3074 )
GL_SCISSOR_BOX=Constant( 'GL_SCISSOR_BOX', 3088 )
GL_SCISSOR_TEST=Constant( 'GL_SCISSOR_TEST', 3089 )
GL_INDEX_CLEAR_VALUE=Constant( 'GL_INDEX_CLEAR_VALUE', 3104 )
GL_INDEX_WRITEMASK=Constant( 'GL_INDEX_WRITEMASK', 3105 )
GL_COLOR_CLEAR_VALUE=Constant( 'GL_COLOR_CLEAR_VALUE', 3106 )
GL_COLOR_WRITEMASK=Constant( 'GL_COLOR_WRITEMASK', 3107 )
GL_INDEX_MODE=Constant( 'GL_INDEX_MODE', 3120 )
GL_RGBA_MODE=Constant( 'GL_RGBA_MODE', 3121 )
GL_DOUBLEBUFFER=Constant( 'GL_DOUBLEBUFFER', 3122 )
GL_STEREO=Constant( 'GL_STEREO', 3123 )
GL_RENDER_MODE=Constant( 'GL_RENDER_MODE', 3136 )
GL_PERSPECTIVE_CORRECTION_HINT=Constant( 'GL_PERSPECTIVE_CORRECTION_HINT', 3152 )
GL_POINT_SMOOTH_HINT=Constant( 'GL_POINT_SMOOTH_HINT', 3153 )
GL_LINE_SMOOTH_HINT=Constant( 'GL_LINE_SMOOTH_HINT', 3154 )
GL_POLYGON_SMOOTH_HINT=Constant( 'GL_POLYGON_SMOOTH_HINT', 3155 )
GL_FOG_HINT=Constant( 'GL_FOG_HINT', 3156 )
GL_TEXTURE_GEN_S=Constant( 'GL_TEXTURE_GEN_S', 3168 )
GL_TEXTURE_GEN_T=Constant( 'GL_TEXTURE_GEN_T', 3169 )
GL_TEXTURE_GEN_R=Constant( 'GL_TEXTURE_GEN_R', 3170 )
GL_TEXTURE_GEN_Q=Constant( 'GL_TEXTURE_GEN_Q', 3171 )
GL_PIXEL_MAP_I_TO_I_SIZE=Constant( 'GL_PIXEL_MAP_I_TO_I_SIZE', 3248 )
GL_PIXEL_MAP_S_TO_S_SIZE=Constant( 'GL_PIXEL_MAP_S_TO_S_SIZE', 3249 )
GL_PIXEL_MAP_I_TO_R_SIZE=Constant( 'GL_PIXEL_MAP_I_TO_R_SIZE', 3250 )
GL_PIXEL_MAP_I_TO_G_SIZE=Constant( 'GL_PIXEL_MAP_I_TO_G_SIZE', 3251 )
GL_PIXEL_MAP_I_TO_B_SIZE=Constant( 'GL_PIXEL_MAP_I_TO_B_SIZE', 3252 )
GL_PIXEL_MAP_I_TO_A_SIZE=Constant( 'GL_PIXEL_MAP_I_TO_A_SIZE', 3253 )
GL_PIXEL_MAP_R_TO_R_SIZE=Constant( 'GL_PIXEL_MAP_R_TO_R_SIZE', 3254 )
GL_PIXEL_MAP_G_TO_G_SIZE=Constant( 'GL_PIXEL_MAP_G_TO_G_SIZE', 3255 )
GL_PIXEL_MAP_B_TO_B_SIZE=Constant( 'GL_PIXEL_MAP_B_TO_B_SIZE', 3256 )
GL_PIXEL_MAP_A_TO_A_SIZE=Constant( 'GL_PIXEL_MAP_A_TO_A_SIZE', 3257 )
GL_UNPACK_SWAP_BYTES=Constant( 'GL_UNPACK_SWAP_BYTES', 3312 )
GL_UNPACK_LSB_FIRST=Constant( 'GL_UNPACK_LSB_FIRST', 3313 )
GL_UNPACK_ROW_LENGTH=Constant( 'GL_UNPACK_ROW_LENGTH', 3314 )
GL_UNPACK_SKIP_ROWS=Constant( 'GL_UNPACK_SKIP_ROWS', 3315 )
GL_UNPACK_SKIP_PIXELS=Constant( 'GL_UNPACK_SKIP_PIXELS', 3316 )
GL_UNPACK_ALIGNMENT=Constant( 'GL_UNPACK_ALIGNMENT', 3317 )
GL_PACK_SWAP_BYTES=Constant( 'GL_PACK_SWAP_BYTES', 3328 )
GL_PACK_LSB_FIRST=Constant( 'GL_PACK_LSB_FIRST', 3329 )
GL_PACK_ROW_LENGTH=Constant( 'GL_PACK_ROW_LENGTH', 3330 )
GL_PACK_SKIP_ROWS=Constant( 'GL_PACK_SKIP_ROWS', 3331 )
GL_PACK_SKIP_PIXELS=Constant( 'GL_PACK_SKIP_PIXELS', 3332 )
GL_PACK_ALIGNMENT=Constant( 'GL_PACK_ALIGNMENT', 3333 )
GL_MAP_COLOR=Constant( 'GL_MAP_COLOR', 3344 )
GL_MAP_STENCIL=Constant( 'GL_MAP_STENCIL', 3345 )
GL_INDEX_SHIFT=Constant( 'GL_INDEX_SHIFT', 3346 )
GL_INDEX_OFFSET=Constant( 'GL_INDEX_OFFSET', 3347 )
GL_RED_SCALE=Constant( 'GL_RED_SCALE', 3348 )
GL_RED_BIAS=Constant( 'GL_RED_BIAS', 3349 )
GL_ZOOM_X=Constant( 'GL_ZOOM_X', 3350 )
GL_ZOOM_Y=Constant( 'GL_ZOOM_Y', 3351 )
GL_GREEN_SCALE=Constant( 'GL_GREEN_SCALE', 3352 )
GL_GREEN_BIAS=Constant( 'GL_GREEN_BIAS', 3353 )
GL_BLUE_SCALE=Constant( 'GL_BLUE_SCALE', 3354 )
GL_BLUE_BIAS=Constant( 'GL_BLUE_BIAS', 3355 )
GL_ALPHA_SCALE=Constant( 'GL_ALPHA_SCALE', 3356 )
GL_ALPHA_BIAS=Constant( 'GL_ALPHA_BIAS', 3357 )
GL_DEPTH_SCALE=Constant( 'GL_DEPTH_SCALE', 3358 )
GL_DEPTH_BIAS=Constant( 'GL_DEPTH_BIAS', 3359 )
GL_MAX_EVAL_ORDER=Constant( 'GL_MAX_EVAL_ORDER', 3376 )
GL_MAX_LIGHTS=Constant( 'GL_MAX_LIGHTS', 3377 )
GL_MAX_CLIP_PLANES=Constant( 'GL_MAX_CLIP_PLANES', 3378 )
GL_MAX_TEXTURE_SIZE=Constant( 'GL_MAX_TEXTURE_SIZE', 3379 )
GL_MAX_PIXEL_MAP_TABLE=Constant( 'GL_MAX_PIXEL_MAP_TABLE', 3380 )
GL_MAX_ATTRIB_STACK_DEPTH=Constant( 'GL_MAX_ATTRIB_STACK_DEPTH', 3381 )
GL_MAX_MODELVIEW_STACK_DEPTH=Constant( 'GL_MAX_MODELVIEW_STACK_DEPTH', 3382 )
GL_MAX_NAME_STACK_DEPTH=Constant( 'GL_MAX_NAME_STACK_DEPTH', 3383 )
GL_MAX_PROJECTION_STACK_DEPTH=Constant( 'GL_MAX_PROJECTION_STACK_DEPTH', 3384 )
GL_MAX_TEXTURE_STACK_DEPTH=Constant( 'GL_MAX_TEXTURE_STACK_DEPTH', 3385 )
GL_MAX_VIEWPORT_DIMS=Constant( 'GL_MAX_VIEWPORT_DIMS', 3386 )
GL_MAX_CLIENT_ATTRIB_STACK_DEPTH=Constant( 'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH', 3387 )
GL_SUBPIXEL_BITS=Constant( 'GL_SUBPIXEL_BITS', 3408 )
GL_INDEX_BITS=Constant( 'GL_INDEX_BITS', 3409 )
GL_RED_BITS=Constant( 'GL_RED_BITS', 3410 )
GL_GREEN_BITS=Constant( 'GL_GREEN_BITS', 3411 )
GL_BLUE_BITS=Constant( 'GL_BLUE_BITS', 3412 )
GL_ALPHA_BITS=Constant( 'GL_ALPHA_BITS', 3413 )
GL_DEPTH_BITS=Constant( 'GL_DEPTH_BITS', 3414 )
GL_STENCIL_BITS=Constant( 'GL_STENCIL_BITS', 3415 )
GL_ACCUM_RED_BITS=Constant( 'GL_ACCUM_RED_BITS', 3416 )
GL_ACCUM_GREEN_BITS=Constant( 'GL_ACCUM_GREEN_BITS', 3417 )
GL_ACCUM_BLUE_BITS=Constant( 'GL_ACCUM_BLUE_BITS', 3418 )
GL_ACCUM_ALPHA_BITS=Constant( 'GL_ACCUM_ALPHA_BITS', 3419 )
GL_NAME_STACK_DEPTH=Constant( 'GL_NAME_STACK_DEPTH', 3440 )
GL_AUTO_NORMAL=Constant( 'GL_AUTO_NORMAL', 3456 )
GL_MAP1_COLOR_4=Constant( 'GL_MAP1_COLOR_4', 3472 )
GL_MAP1_INDEX=Constant( 'GL_MAP1_INDEX', 3473 )
GL_MAP1_NORMAL=Constant( 'GL_MAP1_NORMAL', 3474 )
GL_MAP1_TEXTURE_COORD_1=Constant( 'GL_MAP1_TEXTURE_COORD_1', 3475 )
GL_MAP1_TEXTURE_COORD_2=Constant( 'GL_MAP1_TEXTURE_COORD_2', 3476 )
GL_MAP1_TEXTURE_COORD_3=Constant( 'GL_MAP1_TEXTURE_COORD_3', 3477 )
GL_MAP1_TEXTURE_COORD_4=Constant( 'GL_MAP1_TEXTURE_COORD_4', 3478 )
GL_MAP1_VERTEX_3=Constant( 'GL_MAP1_VERTEX_3', 3479 )
GL_MAP1_VERTEX_4=Constant( 'GL_MAP1_VERTEX_4', 3480 )
GL_MAP2_COLOR_4=Constant( 'GL_MAP2_COLOR_4', 3504 )
GL_MAP2_INDEX=Constant( 'GL_MAP2_INDEX', 3505 )
GL_MAP2_NORMAL=Constant( 'GL_MAP2_NORMAL', 3506 )
GL_MAP2_TEXTURE_COORD_1=Constant( 'GL_MAP2_TEXTURE_COORD_1', 3507 )
GL_MAP2_TEXTURE_COORD_2=Constant( 'GL_MAP2_TEXTURE_COORD_2', 3508 )
GL_MAP2_TEXTURE_COORD_3=Constant( 'GL_MAP2_TEXTURE_COORD_3', 3509 )
GL_MAP2_TEXTURE_COORD_4=Constant( 'GL_MAP2_TEXTURE_COORD_4', 3510 )
GL_MAP2_VERTEX_3=Constant( 'GL_MAP2_VERTEX_3', 3511 )
GL_MAP2_VERTEX_4=Constant( 'GL_MAP2_VERTEX_4', 3512 )
GL_MAP1_GRID_DOMAIN=Constant( 'GL_MAP1_GRID_DOMAIN', 3536 )
GL_MAP1_GRID_SEGMENTS=Constant( 'GL_MAP1_GRID_SEGMENTS', 3537 )
GL_MAP2_GRID_DOMAIN=Constant( 'GL_MAP2_GRID_DOMAIN', 3538 )
GL_MAP2_GRID_SEGMENTS=Constant( 'GL_MAP2_GRID_SEGMENTS', 3539 )
GL_TEXTURE_1D=Constant( 'GL_TEXTURE_1D', 3552 )
GL_TEXTURE_2D=Constant( 'GL_TEXTURE_2D', 3553 )
GL_FEEDBACK_BUFFER_POINTER=Constant( 'GL_FEEDBACK_BUFFER_POINTER', 3568 )
GL_FEEDBACK_BUFFER_SIZE=Constant( 'GL_FEEDBACK_BUFFER_SIZE', 3569 )
GL_FEEDBACK_BUFFER_TYPE=Constant( 'GL_FEEDBACK_BUFFER_TYPE', 3570 )
GL_SELECTION_BUFFER_POINTER=Constant( 'GL_SELECTION_BUFFER_POINTER', 3571 )
GL_SELECTION_BUFFER_SIZE=Constant( 'GL_SELECTION_BUFFER_SIZE', 3572 )
GL_POLYGON_OFFSET_UNITS=Constant( 'GL_POLYGON_OFFSET_UNITS', 10752 )
GL_POLYGON_OFFSET_POINT=Constant( 'GL_POLYGON_OFFSET_POINT', 10753 )
GL_POLYGON_OFFSET_LINE=Constant( 'GL_POLYGON_OFFSET_LINE', 10754 )
GL_POLYGON_OFFSET_FILL=Constant( 'GL_POLYGON_OFFSET_FILL', 32823 )
GL_POLYGON_OFFSET_FACTOR=Constant( 'GL_POLYGON_OFFSET_FACTOR', 32824 )
GL_TEXTURE_BINDING_1D=Constant( 'GL_TEXTURE_BINDING_1D', 32872 )
GL_TEXTURE_BINDING_2D=Constant( 'GL_TEXTURE_BINDING_2D', 32873 )
GL_TEXTURE_BINDING_3D=Constant( 'GL_TEXTURE_BINDING_3D', 32874 )
GL_VERTEX_ARRAY=Constant( 'GL_VERTEX_ARRAY', 32884 )
GL_NORMAL_ARRAY=Constant( 'GL_NORMAL_ARRAY', 32885 )
GL_COLOR_ARRAY=Constant( 'GL_COLOR_ARRAY', 32886 )
GL_INDEX_ARRAY=Constant( 'GL_INDEX_ARRAY', 32887 )
GL_TEXTURE_COORD_ARRAY=Constant( 'GL_TEXTURE_COORD_ARRAY', 32888 )
GL_EDGE_FLAG_ARRAY=Constant( 'GL_EDGE_FLAG_ARRAY', 32889 )
GL_VERTEX_ARRAY_SIZE=Constant( 'GL_VERTEX_ARRAY_SIZE', 32890 )
GL_VERTEX_ARRAY_TYPE=Constant( 'GL_VERTEX_ARRAY_TYPE', 32891 )
GL_VERTEX_ARRAY_STRIDE=Constant( 'GL_VERTEX_ARRAY_STRIDE', 32892 )
GL_NORMAL_ARRAY_TYPE=Constant( 'GL_NORMAL_ARRAY_TYPE', 32894 )
GL_NORMAL_ARRAY_STRIDE=Constant( 'GL_NORMAL_ARRAY_STRIDE', 32895 )
GL_COLOR_ARRAY_SIZE=Constant( 'GL_COLOR_ARRAY_SIZE', 32897 )
GL_COLOR_ARRAY_TYPE=Constant( 'GL_COLOR_ARRAY_TYPE', 32898 )
GL_COLOR_ARRAY_STRIDE=Constant( 'GL_COLOR_ARRAY_STRIDE', 32899 )
GL_INDEX_ARRAY_TYPE=Constant( 'GL_INDEX_ARRAY_TYPE', 32901 )
GL_INDEX_ARRAY_STRIDE=Constant( 'GL_INDEX_ARRAY_STRIDE', 32902 )
GL_TEXTURE_COORD_ARRAY_SIZE=Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE', 32904 )
GL_TEXTURE_COORD_ARRAY_TYPE=Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE', 32905 )
GL_TEXTURE_COORD_ARRAY_STRIDE=Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE', 32906 )
GL_EDGE_FLAG_ARRAY_STRIDE=Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE', 32908 )
GL_TEXTURE_WIDTH=Constant( 'GL_TEXTURE_WIDTH', 4096 )
GL_TEXTURE_HEIGHT=Constant( 'GL_TEXTURE_HEIGHT', 4097 )
GL_TEXTURE_INTERNAL_FORMAT=Constant( 'GL_TEXTURE_INTERNAL_FORMAT', 4099 )
GL_TEXTURE_COMPONENTS=Constant( 'GL_TEXTURE_COMPONENTS', 4099 )
GL_TEXTURE_BORDER_COLOR=Constant( 'GL_TEXTURE_BORDER_COLOR', 4100 )
GL_TEXTURE_BORDER=Constant( 'GL_TEXTURE_BORDER', 4101 )
GL_TEXTURE_RED_SIZE=Constant( 'GL_TEXTURE_RED_SIZE', 32860 )
GL_TEXTURE_GREEN_SIZE=Constant( 'GL_TEXTURE_GREEN_SIZE', 32861 )
GL_TEXTURE_BLUE_SIZE=Constant( 'GL_TEXTURE_BLUE_SIZE', 32862 )
GL_TEXTURE_ALPHA_SIZE=Constant( 'GL_TEXTURE_ALPHA_SIZE', 32863 )
GL_TEXTURE_LUMINANCE_SIZE=Constant( 'GL_TEXTURE_LUMINANCE_SIZE', 32864 )
GL_TEXTURE_INTENSITY_SIZE=Constant( 'GL_TEXTURE_INTENSITY_SIZE', 32865 )
GL_TEXTURE_PRIORITY=Constant( 'GL_TEXTURE_PRIORITY', 32870 )
GL_TEXTURE_RESIDENT=Constant( 'GL_TEXTURE_RESIDENT', 32871 )
GL_DONT_CARE=Constant( 'GL_DONT_CARE', 4352 )
GL_FASTEST=Constant( 'GL_FASTEST', 4353 )
GL_NICEST=Constant( 'GL_NICEST', 4354 )
GL_AMBIENT=Constant( 'GL_AMBIENT', 4608 )
GL_DIFFUSE=Constant( 'GL_DIFFUSE', 4609 )
GL_SPECULAR=Constant( 'GL_SPECULAR', 4610 )
GL_POSITION=Constant( 'GL_POSITION', 4611 )
GL_SPOT_DIRECTION=Constant( 'GL_SPOT_DIRECTION', 4612 )
GL_SPOT_EXPONENT=Constant( 'GL_SPOT_EXPONENT', 4613 )
GL_SPOT_CUTOFF=Constant( 'GL_SPOT_CUTOFF', 4614 )
GL_CONSTANT_ATTENUATION=Constant( 'GL_CONSTANT_ATTENUATION', 4615 )
GL_LINEAR_ATTENUATION=Constant( 'GL_LINEAR_ATTENUATION', 4616 )
GL_QUADRATIC_ATTENUATION=Constant( 'GL_QUADRATIC_ATTENUATION', 4617 )
GL_COMPILE=Constant( 'GL_COMPILE', 4864 )
GL_COMPILE_AND_EXECUTE=Constant( 'GL_COMPILE_AND_EXECUTE', 4865 )
GL_BYTE=Constant( 'GL_BYTE', 5120 )
GL_UNSIGNED_BYTE=Constant( 'GL_UNSIGNED_BYTE', 5121 )
GL_SHORT=Constant( 'GL_SHORT', 5122 )
GL_UNSIGNED_SHORT=Constant( 'GL_UNSIGNED_SHORT', 5123 )
GL_INT=Constant( 'GL_INT', 5124 )
GL_UNSIGNED_INT=Constant( 'GL_UNSIGNED_INT', 5125 )
GL_FLOAT=Constant( 'GL_FLOAT', 5126 )
GL_2_BYTES=Constant( 'GL_2_BYTES', 5127 )
GL_3_BYTES=Constant( 'GL_3_BYTES', 5128 )
GL_4_BYTES=Constant( 'GL_4_BYTES', 5129 )
GL_DOUBLE=Constant( 'GL_DOUBLE', 5130 )
GL_DOUBLE_EXT=Constant( 'GL_DOUBLE_EXT', 5130 )
GL_CLEAR=Constant( 'GL_CLEAR', 5376 )
GL_AND=Constant( 'GL_AND', 5377 )
GL_AND_REVERSE=Constant( 'GL_AND_REVERSE', 5378 )
GL_COPY=Constant( 'GL_COPY', 5379 )
GL_AND_INVERTED=Constant( 'GL_AND_INVERTED', 5380 )
GL_NOOP=Constant( 'GL_NOOP', 5381 )
GL_XOR=Constant( 'GL_XOR', 5382 )
GL_OR=Constant( 'GL_OR', 5383 )
GL_NOR=Constant( 'GL_NOR', 5384 )
GL_EQUIV=Constant( 'GL_EQUIV', 5385 )
GL_INVERT=Constant( 'GL_INVERT', 5386 )
GL_OR_REVERSE=Constant( 'GL_OR_REVERSE', 5387 )
GL_COPY_INVERTED=Constant( 'GL_COPY_INVERTED', 5388 )
GL_OR_INVERTED=Constant( 'GL_OR_INVERTED', 5389 )
GL_NAND=Constant( 'GL_NAND', 5390 )
GL_SET=Constant( 'GL_SET', 5391 )
GL_EMISSION=Constant( 'GL_EMISSION', 5632 )
GL_SHININESS=Constant( 'GL_SHININESS', 5633 )
GL_AMBIENT_AND_DIFFUSE=Constant( 'GL_AMBIENT_AND_DIFFUSE', 5634 )
GL_COLOR_INDEXES=Constant( 'GL_COLOR_INDEXES', 5635 )
GL_MODELVIEW=Constant( 'GL_MODELVIEW', 5888 )
GL_PROJECTION=Constant( 'GL_PROJECTION', 5889 )
GL_TEXTURE=Constant( 'GL_TEXTURE', 5890 )
GL_COLOR=Constant( 'GL_COLOR', 6144 )
GL_DEPTH=Constant( 'GL_DEPTH', 6145 )
GL_STENCIL=Constant( 'GL_STENCIL', 6146 )
GL_COLOR_INDEX=Constant( 'GL_COLOR_INDEX', 6400 )
GL_STENCIL_INDEX=Constant( 'GL_STENCIL_INDEX', 6401 )
GL_DEPTH_COMPONENT=Constant( 'GL_DEPTH_COMPONENT', 6402 )
GL_RED=Constant( 'GL_RED', 6403 )
GL_GREEN=Constant( 'GL_GREEN', 6404 )
GL_BLUE=Constant( 'GL_BLUE', 6405 )
GL_ALPHA=Constant( 'GL_ALPHA', 6406 )
GL_RGB=Constant( 'GL_RGB', 6407 )
GL_RGBA=Constant( 'GL_RGBA', 6408 )
GL_LUMINANCE=Constant( 'GL_LUMINANCE', 6409 )
GL_LUMINANCE_ALPHA=Constant( 'GL_LUMINANCE_ALPHA', 6410 )
GL_BITMAP=Constant( 'GL_BITMAP', 6656 )
GL_POINT=Constant( 'GL_POINT', 6912 )
GL_LINE=Constant( 'GL_LINE', 6913 )
GL_FILL=Constant( 'GL_FILL', 6914 )
GL_RENDER=Constant( 'GL_RENDER', 7168 )
GL_FEEDBACK=Constant( 'GL_FEEDBACK', 7169 )
GL_SELECT=Constant( 'GL_SELECT', 7170 )
GL_FLAT=Constant( 'GL_FLAT', 7424 )
GL_SMOOTH=Constant( 'GL_SMOOTH', 7425 )
GL_KEEP=Constant( 'GL_KEEP', 7680 )
GL_REPLACE=Constant( 'GL_REPLACE', 7681 )
GL_INCR=Constant( 'GL_INCR', 7682 )
GL_DECR=Constant( 'GL_DECR', 7683 )
GL_VENDOR=Constant( 'GL_VENDOR', 7936 )
GL_RENDERER=Constant( 'GL_RENDERER', 7937 )
GL_VERSION=Constant( 'GL_VERSION', 7938 )
GL_EXTENSIONS=Constant( 'GL_EXTENSIONS', 7939 )
GL_S=Constant( 'GL_S', 8192 )
GL_T=Constant( 'GL_T', 8193 )
GL_R=Constant( 'GL_R', 8194 )
GL_Q=Constant( 'GL_Q', 8195 )
GL_MODULATE=Constant( 'GL_MODULATE', 8448 )
GL_DECAL=Constant( 'GL_DECAL', 8449 )
GL_TEXTURE_ENV_MODE=Constant( 'GL_TEXTURE_ENV_MODE', 8704 )
GL_TEXTURE_ENV_COLOR=Constant( 'GL_TEXTURE_ENV_COLOR', 8705 )
GL_TEXTURE_ENV=Constant( 'GL_TEXTURE_ENV', 8960 )
GL_EYE_LINEAR=Constant( 'GL_EYE_LINEAR', 9216 )
GL_OBJECT_LINEAR=Constant( 'GL_OBJECT_LINEAR', 9217 )
GL_SPHERE_MAP=Constant( 'GL_SPHERE_MAP', 9218 )
GL_TEXTURE_GEN_MODE=Constant( 'GL_TEXTURE_GEN_MODE', 9472 )
GL_OBJECT_PLANE=Constant( 'GL_OBJECT_PLANE', 9473 )
GL_EYE_PLANE=Constant( 'GL_EYE_PLANE', 9474 )
GL_NEAREST=Constant( 'GL_NEAREST', 9728 )
GL_LINEAR=Constant( 'GL_LINEAR', 9729 )
GL_NEAREST_MIPMAP_NEAREST=Constant( 'GL_NEAREST_MIPMAP_NEAREST', 9984 )
GL_LINEAR_MIPMAP_NEAREST=Constant( 'GL_LINEAR_MIPMAP_NEAREST', 9985 )
GL_NEAREST_MIPMAP_LINEAR=Constant( 'GL_NEAREST_MIPMAP_LINEAR', 9986 )
GL_LINEAR_MIPMAP_LINEAR=Constant( 'GL_LINEAR_MIPMAP_LINEAR', 9987 )
GL_TEXTURE_MAG_FILTER=Constant( 'GL_TEXTURE_MAG_FILTER', 10240 )
GL_TEXTURE_MIN_FILTER=Constant( 'GL_TEXTURE_MIN_FILTER', 10241 )
GL_TEXTURE_WRAP_S=Constant( 'GL_TEXTURE_WRAP_S', 10242 )
GL_TEXTURE_WRAP_T=Constant( 'GL_TEXTURE_WRAP_T', 10243 )
GL_PROXY_TEXTURE_1D=Constant( 'GL_PROXY_TEXTURE_1D', 32867 )
GL_PROXY_TEXTURE_2D=Constant( 'GL_PROXY_TEXTURE_2D', 32868 )
GL_CLAMP=Constant( 'GL_CLAMP', 10496 )
GL_REPEAT=Constant( 'GL_REPEAT', 10497 )
GL_R3_G3_B2=Constant( 'GL_R3_G3_B2', 10768 )
GL_ALPHA4=Constant( 'GL_ALPHA4', 32827 )
GL_ALPHA8=Constant( 'GL_ALPHA8', 32828 )
GL_ALPHA12=Constant( 'GL_ALPHA12', 32829 )
GL_ALPHA16=Constant( 'GL_ALPHA16', 32830 )
GL_LUMINANCE4=Constant( 'GL_LUMINANCE4', 32831 )
GL_LUMINANCE8=Constant( 'GL_LUMINANCE8', 32832 )
GL_LUMINANCE12=Constant( 'GL_LUMINANCE12', 32833 )
GL_LUMINANCE16=Constant( 'GL_LUMINANCE16', 32834 )
GL_LUMINANCE4_ALPHA4=Constant( 'GL_LUMINANCE4_ALPHA4', 32835 )
GL_LUMINANCE6_ALPHA2=Constant( 'GL_LUMINANCE6_ALPHA2', 32836 )
GL_LUMINANCE8_ALPHA8=Constant( 'GL_LUMINANCE8_ALPHA8', 32837 )
GL_LUMINANCE12_ALPHA4=Constant( 'GL_LUMINANCE12_ALPHA4', 32838 )
GL_LUMINANCE12_ALPHA12=Constant( 'GL_LUMINANCE12_ALPHA12', 32839 )
GL_LUMINANCE16_ALPHA16=Constant( 'GL_LUMINANCE16_ALPHA16', 32840 )
GL_INTENSITY=Constant( 'GL_INTENSITY', 32841 )
GL_INTENSITY4=Constant( 'GL_INTENSITY4', 32842 )
GL_INTENSITY8=Constant( 'GL_INTENSITY8', 32843 )
GL_INTENSITY12=Constant( 'GL_INTENSITY12', 32844 )
GL_INTENSITY16=Constant( 'GL_INTENSITY16', 32845 )
GL_RGB4=Constant( 'GL_RGB4', 32847 )
GL_RGB5=Constant( 'GL_RGB5', 32848 )
GL_RGB8=Constant( 'GL_RGB8', 32849 )
GL_RGB10=Constant( 'GL_RGB10', 32850 )
GL_RGB12=Constant( 'GL_RGB12', 32851 )
GL_RGB16=Constant( 'GL_RGB16', 32852 )
GL_RGBA2=Constant( 'GL_RGBA2', 32853 )
GL_RGBA4=Constant( 'GL_RGBA4', 32854 )
GL_RGB5_A1=Constant( 'GL_RGB5_A1', 32855 )
GL_RGBA8=Constant( 'GL_RGBA8', 32856 )
GL_RGB10_A2=Constant( 'GL_RGB10_A2', 32857 )
GL_RGBA12=Constant( 'GL_RGBA12', 32858 )
GL_RGBA16=Constant( 'GL_RGBA16', 32859 )
GL_V2F=Constant( 'GL_V2F', 10784 )
GL_V3F=Constant( 'GL_V3F', 10785 )
GL_C4UB_V2F=Constant( 'GL_C4UB_V2F', 10786 )
GL_C4UB_V3F=Constant( 'GL_C4UB_V3F', 10787 )
GL_C3F_V3F=Constant( 'GL_C3F_V3F', 10788 )
GL_N3F_V3F=Constant( 'GL_N3F_V3F', 10789 )
GL_C4F_N3F_V3F=Constant( 'GL_C4F_N3F_V3F', 10790 )
GL_T2F_V3F=Constant( 'GL_T2F_V3F', 10791 )
GL_T4F_V4F=Constant( 'GL_T4F_V4F', 10792 )
GL_T2F_C4UB_V3F=Constant( 'GL_T2F_C4UB_V3F', 10793 )
GL_T2F_C3F_V3F=Constant( 'GL_T2F_C3F_V3F', 10794 )
GL_T2F_N3F_V3F=Constant( 'GL_T2F_N3F_V3F', 10795 )
GL_T2F_C4F_N3F_V3F=Constant( 'GL_T2F_C4F_N3F_V3F', 10796 )
GL_T4F_C4F_N3F_V4F=Constant( 'GL_T4F_C4F_N3F_V4F', 10797 )
GL_CLIP_PLANE0=Constant( 'GL_CLIP_PLANE0', 12288 )
GL_CLIP_PLANE1=Constant( 'GL_CLIP_PLANE1', 12289 )
GL_CLIP_PLANE2=Constant( 'GL_CLIP_PLANE2', 12290 )
GL_CLIP_PLANE3=Constant( 'GL_CLIP_PLANE3', 12291 )
GL_CLIP_PLANE4=Constant( 'GL_CLIP_PLANE4', 12292 )
GL_CLIP_PLANE5=Constant( 'GL_CLIP_PLANE5', 12293 )
GL_LIGHT0=Constant( 'GL_LIGHT0', 16384 )
GL_LIGHT1=Constant( 'GL_LIGHT1', 16385 )
GL_LIGHT2=Constant( 'GL_LIGHT2', 16386 )
GL_LIGHT3=Constant( 'GL_LIGHT3', 16387 )
GL_LIGHT4=Constant( 'GL_LIGHT4', 16388 )
GL_LIGHT5=Constant( 'GL_LIGHT5', 16389 )
GL_LIGHT6=Constant( 'GL_LIGHT6', 16390 )
GL_LIGHT7=Constant( 'GL_LIGHT7', 16391 )
GL_ABGR_EXT=Constant( 'GL_ABGR_EXT', 32768 )
GL_FUNC_SUBTRACT_EXT=Constant( 'GL_FUNC_SUBTRACT_EXT', 32778 )
GL_FUNC_REVERSE_SUBTRACT_EXT=Constant( 'GL_FUNC_REVERSE_SUBTRACT_EXT', 32779 )
GL_UNSIGNED_BYTE_3_3_2_EXT=Constant( 'GL_UNSIGNED_BYTE_3_3_2_EXT', 32818 )
GL_UNSIGNED_SHORT_4_4_4_4_EXT=Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 32819 )
GL_UNSIGNED_SHORT_5_5_5_1_EXT=Constant( 'GL_UNSIGNED_SHORT_5_5_5_1_EXT', 32820 )
GL_UNSIGNED_INT_8_8_8_8_EXT=Constant( 'GL_UNSIGNED_INT_8_8_8_8_EXT', 32821 )
GL_UNSIGNED_INT_10_10_10_2_EXT=Constant( 'GL_UNSIGNED_INT_10_10_10_2_EXT', 32822 )
GL_PACK_SKIP_IMAGES=Constant( 'GL_PACK_SKIP_IMAGES', 32875 )
GL_PACK_IMAGE_HEIGHT=Constant( 'GL_PACK_IMAGE_HEIGHT', 32876 )
GL_UNPACK_SKIP_IMAGES=Constant( 'GL_UNPACK_SKIP_IMAGES', 32877 )
GL_UNPACK_IMAGE_HEIGHT=Constant( 'GL_UNPACK_IMAGE_HEIGHT', 32878 )
GL_TEXTURE_3D=Constant( 'GL_TEXTURE_3D', 32879 )
GL_PROXY_TEXTURE_3D=Constant( 'GL_PROXY_TEXTURE_3D', 32880 )
GL_TEXTURE_DEPTH=Constant( 'GL_TEXTURE_DEPTH', 32881 )
GL_TEXTURE_WRAP_R=Constant( 'GL_TEXTURE_WRAP_R', 32882 )
GL_MAX_3D_TEXTURE_SIZE=Constant( 'GL_MAX_3D_TEXTURE_SIZE', 32883 )
GL_BGR=Constant( 'GL_BGR', 32992 )
GL_BGRA=Constant( 'GL_BGRA', 32993 )
GL_UNSIGNED_BYTE_3_3_2=Constant( 'GL_UNSIGNED_BYTE_3_3_2', 32818 )
GL_UNSIGNED_BYTE_2_3_3_REV=Constant( 'GL_UNSIGNED_BYTE_2_3_3_REV', 33634 )
GL_UNSIGNED_SHORT_5_6_5=Constant( 'GL_UNSIGNED_SHORT_5_6_5', 33635 )
GL_UNSIGNED_SHORT_5_6_5_REV=Constant( 'GL_UNSIGNED_SHORT_5_6_5_REV', 33636 )
GL_UNSIGNED_SHORT_4_4_4_4=Constant( 'GL_UNSIGNED_SHORT_4_4_4_4', 32819 )
GL_UNSIGNED_SHORT_4_4_4_4_REV=Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_REV', 33637 )
GL_UNSIGNED_SHORT_5_5_5_1=Constant( 'GL_UNSIGNED_SHORT_5_5_5_1', 32820 )
GL_UNSIGNED_SHORT_1_5_5_5_REV=Constant( 'GL_UNSIGNED_SHORT_1_5_5_5_REV', 33638 )
GL_UNSIGNED_INT_8_8_8_8=Constant( 'GL_UNSIGNED_INT_8_8_8_8', 32821 )
GL_UNSIGNED_INT_8_8_8_8_REV=Constant( 'GL_UNSIGNED_INT_8_8_8_8_REV', 33639 )
GL_UNSIGNED_INT_10_10_10_2=Constant( 'GL_UNSIGNED_INT_10_10_10_2', 32822 )
GL_UNSIGNED_INT_2_10_10_10_REV=Constant( 'GL_UNSIGNED_INT_2_10_10_10_REV', 33640 )
GL_RESCALE_NORMAL=Constant( 'GL_RESCALE_NORMAL', 32826 )
GL_LIGHT_MODEL_COLOR_CONTROL=Constant( 'GL_LIGHT_MODEL_COLOR_CONTROL', 33272 )
GL_SINGLE_COLOR=Constant( 'GL_SINGLE_COLOR', 33273 )
GL_SEPARATE_SPECULAR_COLOR=Constant( 'GL_SEPARATE_SPECULAR_COLOR', 33274 )
GL_CLAMP_TO_EDGE=Constant( 'GL_CLAMP_TO_EDGE', 33071 )
GL_TEXTURE_MIN_LOD=Constant( 'GL_TEXTURE_MIN_LOD', 33082 )
GL_TEXTURE_MAX_LOD=Constant( 'GL_TEXTURE_MAX_LOD', 33083 )
GL_TEXTURE_BASE_LEVEL=Constant( 'GL_TEXTURE_BASE_LEVEL', 33084 )
GL_TEXTURE_MAX_LEVEL=Constant( 'GL_TEXTURE_MAX_LEVEL', 33085 )
GL_MAX_ELEMENTS_VERTICES=Constant( 'GL_MAX_ELEMENTS_VERTICES', 33000 )
GL_MAX_ELEMENTS_INDICES=Constant( 'GL_MAX_ELEMENTS_INDICES', 33001 )
GL_ALIASED_POINT_SIZE_RANGE=Constant( 'GL_ALIASED_POINT_SIZE_RANGE', 33901 )
GL_ALIASED_LINE_WIDTH_RANGE=Constant( 'GL_ALIASED_LINE_WIDTH_RANGE', 33902 )
GL_ACTIVE_TEXTURE=Constant( 'GL_ACTIVE_TEXTURE', 34016 )
GL_CLIENT_ACTIVE_TEXTURE=Constant( 'GL_CLIENT_ACTIVE_TEXTURE', 34017 )
GL_MAX_TEXTURE_UNITS=Constant( 'GL_MAX_TEXTURE_UNITS', 34018 )
GL_TEXTURE0=Constant( 'GL_TEXTURE0', 33984 )
GL_TEXTURE1=Constant( 'GL_TEXTURE1', 33985 )
GL_TEXTURE2=Constant( 'GL_TEXTURE2', 33986 )
GL_TEXTURE3=Constant( 'GL_TEXTURE3', 33987 )
GL_TEXTURE4=Constant( 'GL_TEXTURE4', 33988 )
GL_TEXTURE5=Constant( 'GL_TEXTURE5', 33989 )
GL_TEXTURE6=Constant( 'GL_TEXTURE6', 33990 )
GL_TEXTURE7=Constant( 'GL_TEXTURE7', 33991 )
GL_TEXTURE8=Constant( 'GL_TEXTURE8', 33992 )
GL_TEXTURE9=Constant( 'GL_TEXTURE9', 33993 )
GL_TEXTURE10=Constant( 'GL_TEXTURE10', 33994 )
GL_TEXTURE11=Constant( 'GL_TEXTURE11', 33995 )
GL_TEXTURE12=Constant( 'GL_TEXTURE12', 33996 )
GL_TEXTURE13=Constant( 'GL_TEXTURE13', 33997 )
GL_TEXTURE14=Constant( 'GL_TEXTURE14', 33998 )
GL_TEXTURE15=Constant( 'GL_TEXTURE15', 33999 )
GL_TEXTURE16=Constant( 'GL_TEXTURE16', 34000 )
GL_TEXTURE17=Constant( 'GL_TEXTURE17', 34001 )
GL_TEXTURE18=Constant( 'GL_TEXTURE18', 34002 )
GL_TEXTURE19=Constant( 'GL_TEXTURE19', 34003 )
GL_TEXTURE20=Constant( 'GL_TEXTURE20', 34004 )
GL_TEXTURE21=Constant( 'GL_TEXTURE21', 34005 )
GL_TEXTURE22=Constant( 'GL_TEXTURE22', 34006 )
GL_TEXTURE23=Constant( 'GL_TEXTURE23', 34007 )
GL_TEXTURE24=Constant( 'GL_TEXTURE24', 34008 )
GL_TEXTURE25=Constant( 'GL_TEXTURE25', 34009 )
GL_TEXTURE26=Constant( 'GL_TEXTURE26', 34010 )
GL_TEXTURE27=Constant( 'GL_TEXTURE27', 34011 )
GL_TEXTURE28=Constant( 'GL_TEXTURE28', 34012 )
GL_TEXTURE29=Constant( 'GL_TEXTURE29', 34013 )
GL_TEXTURE30=Constant( 'GL_TEXTURE30', 34014 )
GL_TEXTURE31=Constant( 'GL_TEXTURE31', 34015 )
GL_NORMAL_MAP=Constant( 'GL_NORMAL_MAP', 34065 )
GL_REFLECTION_MAP=Constant( 'GL_REFLECTION_MAP', 34066 )
GL_TEXTURE_CUBE_MAP=Constant( 'GL_TEXTURE_CUBE_MAP', 34067 )
GL_TEXTURE_BINDING_CUBE_MAP=Constant( 'GL_TEXTURE_BINDING_CUBE_MAP', 34068 )
GL_TEXTURE_CUBE_MAP_POSITIVE_X=Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 34069 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_X=Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X', 34070 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Y=Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 34071 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y=Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y', 34072 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Z=Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 34073 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z=Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z', 34074 )
GL_PROXY_TEXTURE_CUBE_MAP=Constant( 'GL_PROXY_TEXTURE_CUBE_MAP', 34075 )
GL_MAX_CUBE_MAP_TEXTURE_SIZE=Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 34076 )
GL_COMBINE=Constant( 'GL_COMBINE', 34160 )
GL_COMBINE_RGB=Constant( 'GL_COMBINE_RGB', 34161 )
GL_COMBINE_ALPHA=Constant( 'GL_COMBINE_ALPHA', 34162 )
GL_RGB_SCALE=Constant( 'GL_RGB_SCALE', 34163 )
GL_ADD_SIGNED=Constant( 'GL_ADD_SIGNED', 34164 )
GL_INTERPOLATE=Constant( 'GL_INTERPOLATE', 34165 )
GL_CONSTANT=Constant( 'GL_CONSTANT', 34166 )
GL_PRIMARY_COLOR=Constant( 'GL_PRIMARY_COLOR', 34167 )
GL_PREVIOUS=Constant( 'GL_PREVIOUS', 34168 )
GL_SOURCE0_RGB=Constant( 'GL_SOURCE0_RGB', 34176 )
GL_SOURCE1_RGB=Constant( 'GL_SOURCE1_RGB', 34177 )
GL_SOURCE2_RGB=Constant( 'GL_SOURCE2_RGB', 34178 )
GL_SOURCE0_ALPHA=Constant( 'GL_SOURCE0_ALPHA', 34184 )
GL_SOURCE1_ALPHA=Constant( 'GL_SOURCE1_ALPHA', 34185 )
GL_SOURCE2_ALPHA=Constant( 'GL_SOURCE2_ALPHA', 34186 )
GL_OPERAND0_RGB=Constant( 'GL_OPERAND0_RGB', 34192 )
GL_OPERAND1_RGB=Constant( 'GL_OPERAND1_RGB', 34193 )
GL_OPERAND2_RGB=Constant( 'GL_OPERAND2_RGB', 34194 )
GL_OPERAND0_ALPHA=Constant( 'GL_OPERAND0_ALPHA', 34200 )
GL_OPERAND1_ALPHA=Constant( 'GL_OPERAND1_ALPHA', 34201 )
GL_OPERAND2_ALPHA=Constant( 'GL_OPERAND2_ALPHA', 34202 )
GL_SUBTRACT=Constant( 'GL_SUBTRACT', 34023 )
GL_TRANSPOSE_MODELVIEW_MATRIX=Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX', 34019 )
GL_TRANSPOSE_PROJECTION_MATRIX=Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX', 34020 )
GL_TRANSPOSE_TEXTURE_MATRIX=Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX', 34021 )
GL_TRANSPOSE_COLOR_MATRIX=Constant( 'GL_TRANSPOSE_COLOR_MATRIX', 34022 )
GL_COMPRESSED_ALPHA=Constant( 'GL_COMPRESSED_ALPHA', 34025 )
GL_COMPRESSED_LUMINANCE=Constant( 'GL_COMPRESSED_LUMINANCE', 34026 )
GL_COMPRESSED_LUMINANCE_ALPHA=Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA', 34027 )
GL_COMPRESSED_INTENSITY=Constant( 'GL_COMPRESSED_INTENSITY', 34028 )
GL_COMPRESSED_RGB=Constant( 'GL_COMPRESSED_RGB', 34029 )
GL_COMPRESSED_RGBA=Constant( 'GL_COMPRESSED_RGBA', 34030 )
GL_TEXTURE_COMPRESSION_HINT=Constant( 'GL_TEXTURE_COMPRESSION_HINT', 34031 )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE=Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 34464 )
GL_TEXTURE_COMPRESSED=Constant( 'GL_TEXTURE_COMPRESSED', 34465 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS=Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 34466 )
GL_COMPRESSED_TEXTURE_FORMATS=Constant( 'GL_COMPRESSED_TEXTURE_FORMATS', 34467 )
GL_DOT3_RGB=Constant( 'GL_DOT3_RGB', 34478 )
GL_DOT3_RGBA=Constant( 'GL_DOT3_RGBA', 34479 )
GL_CLAMP_TO_BORDER=Constant( 'GL_CLAMP_TO_BORDER', 33069 )
GL_MULTISAMPLE=Constant( 'GL_MULTISAMPLE', 32925 )
GL_SAMPLE_ALPHA_TO_COVERAGE=Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE', 32926 )
GL_SAMPLE_ALPHA_TO_ONE=Constant( 'GL_SAMPLE_ALPHA_TO_ONE', 32927 )
GL_SAMPLE_COVERAGE=Constant( 'GL_SAMPLE_COVERAGE', 32928 )
GL_SAMPLE_BUFFERS=Constant( 'GL_SAMPLE_BUFFERS', 32936 )
GL_SAMPLES=Constant( 'GL_SAMPLES', 32937 )
GL_SAMPLE_COVERAGE_VALUE=Constant( 'GL_SAMPLE_COVERAGE_VALUE', 32938 )
GL_SAMPLE_COVERAGE_INVERT=Constant( 'GL_SAMPLE_COVERAGE_INVERT', 32939 )
GL_MULTISAMPLE_BIT=Constant( 'GL_MULTISAMPLE_BIT', 536870912 )
GL_VERTEX_ARRAY_EXT=Constant( 'GL_VERTEX_ARRAY_EXT', 32884 )
GL_NORMAL_ARRAY_EXT=Constant( 'GL_NORMAL_ARRAY_EXT', 32885 )
GL_COLOR_ARRAY_EXT=Constant( 'GL_COLOR_ARRAY_EXT', 32886 )
GL_INDEX_ARRAY_EXT=Constant( 'GL_INDEX_ARRAY_EXT', 32887 )
GL_TEXTURE_COORD_ARRAY_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_EXT', 32888 )
GL_EDGE_FLAG_ARRAY_EXT=Constant( 'GL_EDGE_FLAG_ARRAY_EXT', 32889 )
GL_VERTEX_ARRAY_SIZE_EXT=Constant( 'GL_VERTEX_ARRAY_SIZE_EXT', 32890 )
GL_VERTEX_ARRAY_TYPE_EXT=Constant( 'GL_VERTEX_ARRAY_TYPE_EXT', 32891 )
GL_VERTEX_ARRAY_STRIDE_EXT=Constant( 'GL_VERTEX_ARRAY_STRIDE_EXT', 32892 )
GL_VERTEX_ARRAY_COUNT_EXT=Constant( 'GL_VERTEX_ARRAY_COUNT_EXT', 32893 )
GL_NORMAL_ARRAY_TYPE_EXT=Constant( 'GL_NORMAL_ARRAY_TYPE_EXT', 32894 )
GL_NORMAL_ARRAY_STRIDE_EXT=Constant( 'GL_NORMAL_ARRAY_STRIDE_EXT', 32895 )
GL_NORMAL_ARRAY_COUNT_EXT=Constant( 'GL_NORMAL_ARRAY_COUNT_EXT', 32896 )
GL_COLOR_ARRAY_SIZE_EXT=Constant( 'GL_COLOR_ARRAY_SIZE_EXT', 32897 )
GL_COLOR_ARRAY_TYPE_EXT=Constant( 'GL_COLOR_ARRAY_TYPE_EXT', 32898 )
GL_COLOR_ARRAY_STRIDE_EXT=Constant( 'GL_COLOR_ARRAY_STRIDE_EXT', 32899 )
GL_COLOR_ARRAY_COUNT_EXT=Constant( 'GL_COLOR_ARRAY_COUNT_EXT', 32900 )
GL_INDEX_ARRAY_TYPE_EXT=Constant( 'GL_INDEX_ARRAY_TYPE_EXT', 32901 )
GL_INDEX_ARRAY_STRIDE_EXT=Constant( 'GL_INDEX_ARRAY_STRIDE_EXT', 32902 )
GL_INDEX_ARRAY_COUNT_EXT=Constant( 'GL_INDEX_ARRAY_COUNT_EXT', 32903 )
GL_TEXTURE_COORD_ARRAY_SIZE_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 32904 )
GL_TEXTURE_COORD_ARRAY_TYPE_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT', 32905 )
GL_TEXTURE_COORD_ARRAY_STRIDE_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 32906 )
GL_TEXTURE_COORD_ARRAY_COUNT_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT', 32907 )
GL_EDGE_FLAG_ARRAY_STRIDE_EXT=Constant( 'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 32908 )
GL_EDGE_FLAG_ARRAY_COUNT_EXT=Constant( 'GL_EDGE_FLAG_ARRAY_COUNT_EXT', 32909 )
GL_VERTEX_ARRAY_POINTER_EXT=Constant( 'GL_VERTEX_ARRAY_POINTER_EXT', 32910 )
GL_NORMAL_ARRAY_POINTER_EXT=Constant( 'GL_NORMAL_ARRAY_POINTER_EXT', 32911 )
GL_COLOR_ARRAY_POINTER_EXT=Constant( 'GL_COLOR_ARRAY_POINTER_EXT', 32912 )
GL_INDEX_ARRAY_POINTER_EXT=Constant( 'GL_INDEX_ARRAY_POINTER_EXT', 32913 )
GL_TEXTURE_COORD_ARRAY_POINTER_EXT=Constant( 'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 32914 )
GL_EDGE_FLAG_ARRAY_POINTER_EXT=Constant( 'GL_EDGE_FLAG_ARRAY_POINTER_EXT', 32915 )
GL_TEXTURE_MIN_LOD_SGIS=Constant( 'GL_TEXTURE_MIN_LOD_SGIS', 33082 )
GL_TEXTURE_MAX_LOD_SGIS=Constant( 'GL_TEXTURE_MAX_LOD_SGIS', 33083 )
GL_TEXTURE_BASE_LEVEL_SGIS=Constant( 'GL_TEXTURE_BASE_LEVEL_SGIS', 33084 )
GL_TEXTURE_MAX_LEVEL_SGIS=Constant( 'GL_TEXTURE_MAX_LEVEL_SGIS', 33085 )
GL_SHARED_TEXTURE_PALETTE_EXT=Constant( 'GL_SHARED_TEXTURE_PALETTE_EXT', 33275 )
GL_RESCALE_NORMAL_EXT=Constant( 'GL_RESCALE_NORMAL_EXT', 32826 )
GL_TEXTURE_COMPARE_SGIX=Constant( 'GL_TEXTURE_COMPARE_SGIX', 33178 )
GL_TEXTURE_COMPARE_OPERATOR_SGIX=Constant( 'GL_TEXTURE_COMPARE_OPERATOR_SGIX', 33179 )
GL_TEXTURE_LEQUAL_R_SGIX=Constant( 'GL_TEXTURE_LEQUAL_R_SGIX', 33180 )
GL_TEXTURE_GEQUAL_R_SGIX=Constant( 'GL_TEXTURE_GEQUAL_R_SGIX', 33181 )
GL_DEPTH_COMPONENT16_SGIX=Constant( 'GL_DEPTH_COMPONENT16_SGIX', 33189 )
GL_DEPTH_COMPONENT24_SGIX=Constant( 'GL_DEPTH_COMPONENT24_SGIX', 33190 )
GL_DEPTH_COMPONENT32_SGIX=Constant( 'GL_DEPTH_COMPONENT32_SGIX', 33191 )
GL_GENERATE_MIPMAP_SGIS=Constant( 'GL_GENERATE_MIPMAP_SGIS', 33169 )
GL_GENERATE_MIPMAP_HINT_SGIS=Constant( 'GL_GENERATE_MIPMAP_HINT_SGIS', 33170 )
GL_POINT_SIZE_MIN=Constant( 'GL_POINT_SIZE_MIN', 33062 )
GL_POINT_SIZE_MAX=Constant( 'GL_POINT_SIZE_MAX', 33063 )
GL_POINT_FADE_THRESHOLD_SIZE=Constant( 'GL_POINT_FADE_THRESHOLD_SIZE', 33064 )
GL_POINT_DISTANCE_ATTENUATION=Constant( 'GL_POINT_DISTANCE_ATTENUATION', 33065 )
GL_FOG_COORDINATE_SOURCE=Constant( 'GL_FOG_COORDINATE_SOURCE', 33872 )
GL_FOG_COORDINATE=Constant( 'GL_FOG_COORDINATE', 33873 )
GL_FRAGMENT_DEPTH=Constant( 'GL_FRAGMENT_DEPTH', 33874 )
GL_CURRENT_FOG_COORDINATE=Constant( 'GL_CURRENT_FOG_COORDINATE', 33875 )
GL_FOG_COORDINATE_ARRAY_TYPE=Constant( 'GL_FOG_COORDINATE_ARRAY_TYPE', 33876 )
GL_FOG_COORDINATE_ARRAY_STRIDE=Constant( 'GL_FOG_COORDINATE_ARRAY_STRIDE', 33877 )
GL_FOG_COORDINATE_ARRAY_POINTER=Constant( 'GL_FOG_COORDINATE_ARRAY_POINTER', 33878 )
GL_FOG_COORDINATE_ARRAY=Constant( 'GL_FOG_COORDINATE_ARRAY', 33879 )
GL_COLOR_SUM=Constant( 'GL_COLOR_SUM', 33880 )
GL_CURRENT_SECONDARY_COLOR=Constant( 'GL_CURRENT_SECONDARY_COLOR', 33881 )
GL_SECONDARY_COLOR_ARRAY_SIZE=Constant( 'GL_SECONDARY_COLOR_ARRAY_SIZE', 33882 )
GL_SECONDARY_COLOR_ARRAY_TYPE=Constant( 'GL_SECONDARY_COLOR_ARRAY_TYPE', 33883 )
GL_SECONDARY_COLOR_ARRAY_STRIDE=Constant( 'GL_SECONDARY_COLOR_ARRAY_STRIDE', 33884 )
GL_SECONDARY_COLOR_ARRAY_POINTER=Constant( 'GL_SECONDARY_COLOR_ARRAY_POINTER', 33885 )
GL_SECONDARY_COLOR_ARRAY=Constant( 'GL_SECONDARY_COLOR_ARRAY', 33886 )
GL_INCR_WRAP=Constant( 'GL_INCR_WRAP', 34055 )
GL_DECR_WRAP=Constant( 'GL_DECR_WRAP', 34056 )
GL_MAX_TEXTURE_LOD_BIAS=Constant( 'GL_MAX_TEXTURE_LOD_BIAS', 34045 )
GL_TEXTURE_FILTER_CONTROL=Constant( 'GL_TEXTURE_FILTER_CONTROL', 34048 )
GL_TEXTURE_LOD_BIAS=Constant( 'GL_TEXTURE_LOD_BIAS', 34049 )
GL_GENERATE_MIPMAP=Constant( 'GL_GENERATE_MIPMAP', 33169 )
GL_GENERATE_MIPMAP_HINT=Constant( 'GL_GENERATE_MIPMAP_HINT', 33170 )
GL_BLEND_DST_RGB=Constant( 'GL_BLEND_DST_RGB', 32968 )
GL_BLEND_SRC_RGB=Constant( 'GL_BLEND_SRC_RGB', 32969 )
GL_BLEND_DST_ALPHA=Constant( 'GL_BLEND_DST_ALPHA', 32970 )
GL_BLEND_SRC_ALPHA=Constant( 'GL_BLEND_SRC_ALPHA', 32971 )
GL_MIRRORED_REPEAT=Constant( 'GL_MIRRORED_REPEAT', 33648 )
GL_DEPTH_COMPONENT16=Constant( 'GL_DEPTH_COMPONENT16', 33189 )
GL_DEPTH_COMPONENT24=Constant( 'GL_DEPTH_COMPONENT24', 33190 )
GL_DEPTH_COMPONENT32=Constant( 'GL_DEPTH_COMPONENT32', 33191 )
GL_TEXTURE_DEPTH_SIZE=Constant( 'GL_TEXTURE_DEPTH_SIZE', 34890 )
GL_DEPTH_TEXTURE_MODE=Constant( 'GL_DEPTH_TEXTURE_MODE', 34891 )
GL_TEXTURE_COMPARE_MODE=Constant( 'GL_TEXTURE_COMPARE_MODE', 34892 )
GL_TEXTURE_COMPARE_FUNC=Constant( 'GL_TEXTURE_COMPARE_FUNC', 34893 )
GL_COMPARE_R_TO_TEXTURE=Constant( 'GL_COMPARE_R_TO_TEXTURE', 34894 )
glAccum=platform.createBaseFunction(
	'glAccum',platform.GL,None,
	[GLenum,GLfloat],
	['op', 'value'],
)
glAlphaFunc=platform.createBaseFunction(
	'glAlphaFunc',platform.GL,None,
	[GLenum,GLclampf],
	['func', 'ref'],
)
glAreTexturesResident=platform.createBaseFunction(
	'glAreTexturesResident',platform.GL,GLboolean,
	[GLsizei,GLuintArray,GLbooleanArray],
	['n', 'textures', 'residences'],
)
glArrayElement=platform.createBaseFunction(
	'glArrayElement',platform.GL,None,
	[GLint],
	['i'],
)
glBegin=platform.createBaseFunction(
	'glBegin',platform.GL,None,
	[GLenum],
	['mode'],
)
glBindTexture=platform.createBaseFunction(
	'glBindTexture',platform.GL,None,
	[GLenum,GLuint],
	['target', 'texture'],
)
glBitmap=platform.createBaseFunction(
	'glBitmap',platform.GL,None,
	[GLsizei,GLsizei,GLfloat,GLfloat,GLfloat,GLfloat,GLubyteArray],
	['width', 'height', 'xorig', 'yorig', 'xmove', 'ymove', 'bitmap'],
)
glBlendFunc=platform.createBaseFunction(
	'glBlendFunc',platform.GL,None,
	[GLenum,GLenum],
	['sfactor', 'dfactor'],
)
glCallList=platform.createBaseFunction(
	'glCallList',platform.GL,None,
	[GLuint],
	['list'],
)
glCallLists=platform.createBaseFunction(
	'glCallLists',platform.GL,None,
	[GLsizei,GLenum,POINTER(GLvoid)],
	['n', 'type', 'lists'],
)
glClear=platform.createBaseFunction(
	'glClear',platform.GL,None,
	[GLbitfield],
	['mask'],
)
glClearAccum=platform.createBaseFunction(
	'glClearAccum',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['red', 'green', 'blue', 'alpha'],
)
glClearColor=platform.createBaseFunction(
	'glClearColor',platform.GL,None,
	[GLclampf,GLclampf,GLclampf,GLclampf],
	['red', 'green', 'blue', 'alpha'],
)
glClearDepth=platform.createBaseFunction(
	'glClearDepth',platform.GL,None,
	[GLclampd],
	['depth'],
)
glClearIndex=platform.createBaseFunction(
	'glClearIndex',platform.GL,None,
	[GLfloat],
	['c'],
)
glClearStencil=platform.createBaseFunction(
	'glClearStencil',platform.GL,None,
	[GLint],
	['s'],
)
glClipPlane=platform.createBaseFunction(
	'glClipPlane',platform.GL,None,
	[GLenum,GLdoubleArray],
	['plane', 'equation'],
)
glColor3b=platform.createBaseFunction(
	'glColor3b',platform.GL,None,
	[GLbyte,GLbyte,GLbyte],
	['red', 'green', 'blue'],
)
glColor3bv=platform.createBaseFunction(
	'glColor3bv',platform.GL,None,
	[GLbyteArray],
	['v'],
)
glColor3d=platform.createBaseFunction(
	'glColor3d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['red', 'green', 'blue'],
)
glColor3dv=platform.createBaseFunction(
	'glColor3dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glColor3f=platform.createBaseFunction(
	'glColor3f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['red', 'green', 'blue'],
)
glColor3fv=platform.createBaseFunction(
	'glColor3fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glColor3i=platform.createBaseFunction(
	'glColor3i',platform.GL,None,
	[GLint,GLint,GLint],
	['red', 'green', 'blue'],
)
glColor3iv=platform.createBaseFunction(
	'glColor3iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glColor3s=platform.createBaseFunction(
	'glColor3s',platform.GL,None,
	[GLshort,GLshort,GLshort],
	['red', 'green', 'blue'],
)
glColor3sv=platform.createBaseFunction(
	'glColor3sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glColor3ub=platform.createBaseFunction(
	'glColor3ub',platform.GL,None,
	[GLubyte,GLubyte,GLubyte],
	['red', 'green', 'blue'],
)
glColor3ubv=platform.createBaseFunction(
	'glColor3ubv',platform.GL,None,
	[GLubyteArray],
	['v'],
)
glColor3ui=platform.createBaseFunction(
	'glColor3ui',platform.GL,None,
	[GLuint,GLuint,GLuint],
	['red', 'green', 'blue'],
)
glColor3uiv=platform.createBaseFunction(
	'glColor3uiv',platform.GL,None,
	[GLuintArray],
	['v'],
)
glColor3us=platform.createBaseFunction(
	'glColor3us',platform.GL,None,
	[GLushort,GLushort,GLushort],
	['red', 'green', 'blue'],
)
glColor3usv=platform.createBaseFunction(
	'glColor3usv',platform.GL,None,
	[GLushortArray],
	['v'],
)
glColor4b=platform.createBaseFunction(
	'glColor4b',platform.GL,None,
	[GLbyte,GLbyte,GLbyte,GLbyte],
	['red', 'green', 'blue', 'alpha'],
)
glColor4bv=platform.createBaseFunction(
	'glColor4bv',platform.GL,None,
	[GLbyteArray],
	['v'],
)
glColor4d=platform.createBaseFunction(
	'glColor4d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['red', 'green', 'blue', 'alpha'],
)
glColor4dv=platform.createBaseFunction(
	'glColor4dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glColor4f=platform.createBaseFunction(
	'glColor4f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['red', 'green', 'blue', 'alpha'],
)
glColor4fv=platform.createBaseFunction(
	'glColor4fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glColor4i=platform.createBaseFunction(
	'glColor4i',platform.GL,None,
	[GLint,GLint,GLint,GLint],
	['red', 'green', 'blue', 'alpha'],
)
glColor4iv=platform.createBaseFunction(
	'glColor4iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glColor4s=platform.createBaseFunction(
	'glColor4s',platform.GL,None,
	[GLshort,GLshort,GLshort,GLshort],
	['red', 'green', 'blue', 'alpha'],
)
glColor4sv=platform.createBaseFunction(
	'glColor4sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glColor4ub=platform.createBaseFunction(
	'glColor4ub',platform.GL,None,
	[GLubyte,GLubyte,GLubyte,GLubyte],
	['red', 'green', 'blue', 'alpha'],
)
glColor4ubv=platform.createBaseFunction(
	'glColor4ubv',platform.GL,None,
	[GLubyteArray],
	['v'],
)
glColor4ui=platform.createBaseFunction(
	'glColor4ui',platform.GL,None,
	[GLuint,GLuint,GLuint,GLuint],
	['red', 'green', 'blue', 'alpha'],
)
glColor4uiv=platform.createBaseFunction(
	'glColor4uiv',platform.GL,None,
	[GLuintArray],
	['v'],
)
glColor4us=platform.createBaseFunction(
	'glColor4us',platform.GL,None,
	[GLushort,GLushort,GLushort,GLushort],
	['red', 'green', 'blue', 'alpha'],
)
glColor4usv=platform.createBaseFunction(
	'glColor4usv',platform.GL,None,
	[GLushortArray],
	['v'],
)
glColorMask=platform.createBaseFunction(
	'glColorMask',platform.GL,None,
	[GLboolean,GLboolean,GLboolean,GLboolean],
	['red', 'green', 'blue', 'alpha'],
)
glColorMaterial=platform.createBaseFunction(
	'glColorMaterial',platform.GL,None,
	[GLenum,GLenum],
	['face', 'mode'],
)
glColorPointer=platform.createBaseFunction(
	'glColorPointer',platform.GL,None,
	[GLint,GLenum,GLsizei,POINTER(GLvoid)],
	['size', 'type', 'stride', 'pointer'],
)
glCopyPixels=platform.createBaseFunction(
	'glCopyPixels',platform.GL,None,
	[GLint,GLint,GLsizei,GLsizei,GLenum],
	['x', 'y', 'width', 'height', 'type'],
)
glCopyTexImage1D=platform.createBaseFunction(
	'glCopyTexImage1D',platform.GL,None,
	[GLenum,GLint,GLenum,GLint,GLint,GLsizei,GLint],
	['target', 'level', 'internalFormat', 'x', 'y', 'width', 'border'],
)
glCopyTexImage2D=platform.createBaseFunction(
	'glCopyTexImage2D',platform.GL,None,
	[GLenum,GLint,GLenum,GLint,GLint,GLsizei,GLsizei,GLint],
	['target', 'level', 'internalFormat', 'x', 'y', 'width', 'height', 'border'],
)
glCopyTexSubImage1D=platform.createBaseFunction(
	'glCopyTexSubImage1D',platform.GL,None,
	[GLenum,GLint,GLint,GLint,GLint,GLsizei],
	['target', 'level', 'xoffset', 'x', 'y', 'width'],
)
glCopyTexSubImage2D=platform.createBaseFunction(
	'glCopyTexSubImage2D',platform.GL,None,
	[GLenum,GLint,GLint,GLint,GLint,GLint,GLsizei,GLsizei],
	['target', 'level', 'xoffset', 'yoffset', 'x', 'y', 'width', 'height'],
)
glCullFace=platform.createBaseFunction(
	'glCullFace',platform.GL,None,
	[GLenum],
	['mode'],
)
glDeleteLists=platform.createBaseFunction(
	'glDeleteLists',platform.GL,None,
	[GLuint,GLsizei],
	['list', 'range'],
)
glDeleteTextures=platform.createBaseFunction(
	'glDeleteTextures',platform.GL,None,
	[GLsizei,GLuintArray],
	['n', 'textures'],
)
glDepthFunc=platform.createBaseFunction(
	'glDepthFunc',platform.GL,None,
	[GLenum],
	['func'],
)
glDepthMask=platform.createBaseFunction(
	'glDepthMask',platform.GL,None,
	[GLboolean],
	['flag'],
)
glDepthRange=platform.createBaseFunction(
	'glDepthRange',platform.GL,None,
	[GLclampd,GLclampd],
	['zNear', 'zFar'],
)
glDisable=platform.createBaseFunction(
	'glDisable',platform.GL,None,
	[GLenum],
	['cap'],
)
glDisableClientState=platform.createBaseFunction(
	'glDisableClientState',platform.GL,None,
	[GLenum],
	['array'],
)
glDrawArrays=platform.createBaseFunction(
	'glDrawArrays',platform.GL,None,
	[GLenum,GLint,GLsizei],
	['mode', 'first', 'count'],
)
glDrawBuffer=platform.createBaseFunction(
	'glDrawBuffer',platform.GL,None,
	[GLenum],
	['mode'],
)
glDrawElements=platform.createBaseFunction(
	'glDrawElements',platform.GL,None,
	[GLenum,GLsizei,GLenum,POINTER(GLvoid)],
	['mode', 'count', 'type', 'indices'],
)
glDrawPixels=platform.createBaseFunction(
	'glDrawPixels',platform.GL,None,
	[GLsizei,GLsizei,GLenum,GLenum,POINTER(GLvoid)],
	['width', 'height', 'format', 'type', 'pixels'],
)
glEdgeFlag=platform.createBaseFunction(
	'glEdgeFlag',platform.GL,None,
	[GLboolean],
	['flag'],
)
glEdgeFlagPointer=platform.createBaseFunction(
	'glEdgeFlagPointer',platform.GL,None,
	[GLsizei,POINTER(GLvoid)],
	['stride', 'pointer'],
)
glEdgeFlagv=platform.createBaseFunction(
	'glEdgeFlagv',platform.GL,None,
	[GLbooleanArray],
	['flag'],
)
glEnable=platform.createBaseFunction(
	'glEnable',platform.GL,None,
	[GLenum],
	['cap'],
)
glEnableClientState=platform.createBaseFunction(
	'glEnableClientState',platform.GL,None,
	[GLenum],
	['array'],
)
glEnd=platform.createBaseFunction(
	'glEnd',platform.GL,None,
	[],
	[],
)
glEndList=platform.createBaseFunction(
	'glEndList',platform.GL,None,
	[],
	[],
)
glEvalCoord1d=platform.createBaseFunction(
	'glEvalCoord1d',platform.GL,None,
	[GLdouble],
	['u'],
)
glEvalCoord1dv=platform.createBaseFunction(
	'glEvalCoord1dv',platform.GL,None,
	[GLdoubleArray],
	['u'],
)
glEvalCoord1f=platform.createBaseFunction(
	'glEvalCoord1f',platform.GL,None,
	[GLfloat],
	['u'],
)
glEvalCoord1fv=platform.createBaseFunction(
	'glEvalCoord1fv',platform.GL,None,
	[GLfloatArray],
	['u'],
)
glEvalCoord2d=platform.createBaseFunction(
	'glEvalCoord2d',platform.GL,None,
	[GLdouble,GLdouble],
	['u', 'v'],
)
glEvalCoord2dv=platform.createBaseFunction(
	'glEvalCoord2dv',platform.GL,None,
	[GLdoubleArray],
	['u'],
)
glEvalCoord2f=platform.createBaseFunction(
	'glEvalCoord2f',platform.GL,None,
	[GLfloat,GLfloat],
	['u', 'v'],
)
glEvalCoord2fv=platform.createBaseFunction(
	'glEvalCoord2fv',platform.GL,None,
	[GLfloatArray],
	['u'],
)
glEvalMesh1=platform.createBaseFunction(
	'glEvalMesh1',platform.GL,None,
	[GLenum,GLint,GLint],
	['mode', 'i1', 'i2'],
)
glEvalMesh2=platform.createBaseFunction(
	'glEvalMesh2',platform.GL,None,
	[GLenum,GLint,GLint,GLint,GLint],
	['mode', 'i1', 'i2', 'j1', 'j2'],
)
glEvalPoint1=platform.createBaseFunction(
	'glEvalPoint1',platform.GL,None,
	[GLint],
	['i'],
)
glEvalPoint2=platform.createBaseFunction(
	'glEvalPoint2',platform.GL,None,
	[GLint,GLint],
	['i', 'j'],
)
glFeedbackBuffer=platform.createBaseFunction(
	'glFeedbackBuffer',platform.GL,None,
	[GLsizei,GLenum,GLfloatArray],
	['size', 'type', 'buffer'],
)
glFinish=platform.createBaseFunction(
	'glFinish',platform.GL,None,
	[],
	[],
)
glFlush=platform.createBaseFunction(
	'glFlush',platform.GL,None,
	[],
	[],
)
glFogf=platform.createBaseFunction(
	'glFogf',platform.GL,None,
	[GLenum,GLfloat],
	['pname', 'param'],
)
glFogfv=platform.createBaseFunction(
	'glFogfv',platform.GL,None,
	[GLenum,GLfloatArray],
	['pname', 'params'],
)
glFogi=platform.createBaseFunction(
	'glFogi',platform.GL,None,
	[GLenum,GLint],
	['pname', 'param'],
)
glFogiv=platform.createBaseFunction(
	'glFogiv',platform.GL,None,
	[GLenum,GLintArray],
	['pname', 'params'],
)
glFrontFace=platform.createBaseFunction(
	'glFrontFace',platform.GL,None,
	[GLenum],
	['mode'],
)
glFrustum=platform.createBaseFunction(
	'glFrustum',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble],
	['left', 'right', 'bottom', 'top', 'zNear', 'zFar'],
)
glGenLists=platform.createBaseFunction(
	'glGenLists',platform.GL,GLuint,
	[GLsizei],
	['range'],
)
glGenTextures=platform.createBaseFunction(
	'glGenTextures',platform.GL,None,
	[GLsizei,GLuintArray],
	['n', 'textures'],
)
glGetBooleanv=platform.createBaseFunction(
	'glGetBooleanv',platform.GL,None,
	[GLenum,GLbooleanArray],
	['pname', 'params'],
)
glGetClipPlane=platform.createBaseFunction(
	'glGetClipPlane',platform.GL,None,
	[GLenum,GLdoubleArray],
	['plane', 'equation'],
)
glGetDoublev=platform.createBaseFunction(
	'glGetDoublev',platform.GL,None,
	[GLenum,GLdoubleArray],
	['pname', 'params'],
)
glGetError=platform.createBaseFunction(
	'glGetError',platform.GL,GLenum,
	[],
	[],
)
glGetFloatv=platform.createBaseFunction(
	'glGetFloatv',platform.GL,None,
	[GLenum,GLfloatArray],
	['pname', 'params'],
)
glGetIntegerv=platform.createBaseFunction(
	'glGetIntegerv',platform.GL,None,
	[GLenum,GLintArray],
	['pname', 'params'],
)
glGetLightfv=platform.createBaseFunction(
	'glGetLightfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['light', 'pname', 'params'],
)
glGetLightiv=platform.createBaseFunction(
	'glGetLightiv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['light', 'pname', 'params'],
)
glGetMapdv=platform.createBaseFunction(
	'glGetMapdv',platform.GL,None,
	[GLenum,GLenum,GLdoubleArray],
	['target', 'query', 'v'],
)
glGetMapfv=platform.createBaseFunction(
	'glGetMapfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['target', 'query', 'v'],
)
glGetMapiv=platform.createBaseFunction(
	'glGetMapiv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['target', 'query', 'v'],
)
glGetMaterialfv=platform.createBaseFunction(
	'glGetMaterialfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['face', 'pname', 'params'],
)
glGetMaterialiv=platform.createBaseFunction(
	'glGetMaterialiv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['face', 'pname', 'params'],
)
glGetPixelMapfv=platform.createBaseFunction(
	'glGetPixelMapfv',platform.GL,None,
	[GLenum,GLfloatArray],
	['map', 'values'],
)
glGetPixelMapuiv=platform.createBaseFunction(
	'glGetPixelMapuiv',platform.GL,None,
	[GLenum,GLuintArray],
	['map', 'values'],
)
glGetPixelMapusv=platform.createBaseFunction(
	'glGetPixelMapusv',platform.GL,None,
	[GLenum,GLushortArray],
	['map', 'values'],
)
glGetPointerv=platform.createBaseFunction(
	'glGetPointerv',platform.GL,None,
	[GLenum,POINTER(POINTER(GLvoid))],
	['pname', 'params'],
)
glGetPolygonStipple=platform.createBaseFunction(
	'glGetPolygonStipple',platform.GL,None,
	[GLubyteArray],
	['mask'],
)
glGetString=platform.createBaseFunction(
	'glGetString',platform.GL,GLubyteArray,
	[GLenum],
	['name'],
)
glGetTexEnvfv=platform.createBaseFunction(
	'glGetTexEnvfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['target', 'pname', 'params'],
)
glGetTexEnviv=platform.createBaseFunction(
	'glGetTexEnviv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['target', 'pname', 'params'],
)
glGetTexGendv=platform.createBaseFunction(
	'glGetTexGendv',platform.GL,None,
	[GLenum,GLenum,GLdoubleArray],
	['coord', 'pname', 'params'],
)
glGetTexGenfv=platform.createBaseFunction(
	'glGetTexGenfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['coord', 'pname', 'params'],
)
glGetTexGeniv=platform.createBaseFunction(
	'glGetTexGeniv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['coord', 'pname', 'params'],
)
glGetTexImage=platform.createBaseFunction(
	'glGetTexImage',platform.GL,None,
	[GLenum,GLint,GLenum,GLenum,POINTER(GLvoid)],
	['target', 'level', 'format', 'type', 'pixels'],
)
glGetTexLevelParameterfv=platform.createBaseFunction(
	'glGetTexLevelParameterfv',platform.GL,None,
	[GLenum,GLint,GLenum,GLfloatArray],
	['target', 'level', 'pname', 'params'],
)
glGetTexLevelParameteriv=platform.createBaseFunction(
	'glGetTexLevelParameteriv',platform.GL,None,
	[GLenum,GLint,GLenum,GLintArray],
	['target', 'level', 'pname', 'params'],
)
glGetTexParameterfv=platform.createBaseFunction(
	'glGetTexParameterfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['target', 'pname', 'params'],
)
glGetTexParameteriv=platform.createBaseFunction(
	'glGetTexParameteriv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['target', 'pname', 'params'],
)
glHint=platform.createBaseFunction(
	'glHint',platform.GL,None,
	[GLenum,GLenum],
	['target', 'mode'],
)
glIndexMask=platform.createBaseFunction(
	'glIndexMask',platform.GL,None,
	[GLuint],
	['mask'],
)
glIndexPointer=platform.createBaseFunction(
	'glIndexPointer',platform.GL,None,
	[GLenum,GLsizei,POINTER(GLvoid)],
	['type', 'stride', 'pointer'],
)
glIndexd=platform.createBaseFunction(
	'glIndexd',platform.GL,None,
	[GLdouble],
	['c'],
)
glIndexdv=platform.createBaseFunction(
	'glIndexdv',platform.GL,None,
	[GLdoubleArray],
	['c'],
)
glIndexf=platform.createBaseFunction(
	'glIndexf',platform.GL,None,
	[GLfloat],
	['c'],
)
glIndexfv=platform.createBaseFunction(
	'glIndexfv',platform.GL,None,
	[GLfloatArray],
	['c'],
)
glIndexi=platform.createBaseFunction(
	'glIndexi',platform.GL,None,
	[GLint],
	['c'],
)
glIndexiv=platform.createBaseFunction(
	'glIndexiv',platform.GL,None,
	[GLintArray],
	['c'],
)
glIndexs=platform.createBaseFunction(
	'glIndexs',platform.GL,None,
	[GLshort],
	['c'],
)
glIndexsv=platform.createBaseFunction(
	'glIndexsv',platform.GL,None,
	[GLshortArray],
	['c'],
)
glIndexub=platform.createBaseFunction(
	'glIndexub',platform.GL,None,
	[GLubyte],
	['c'],
)
glIndexubv=platform.createBaseFunction(
	'glIndexubv',platform.GL,None,
	[GLubyteArray],
	['c'],
)
glInitNames=platform.createBaseFunction(
	'glInitNames',platform.GL,None,
	[],
	[],
)
glInterleavedArrays=platform.createBaseFunction(
	'glInterleavedArrays',platform.GL,None,
	[GLenum,GLsizei,POINTER(GLvoid)],
	['format', 'stride', 'pointer'],
)
glIsEnabled=platform.createBaseFunction(
	'glIsEnabled',platform.GL,GLboolean,
	[GLenum],
	['cap'],
)
glIsList=platform.createBaseFunction(
	'glIsList',platform.GL,GLboolean,
	[GLuint],
	['list'],
)
glIsTexture=platform.createBaseFunction(
	'glIsTexture',platform.GL,GLboolean,
	[GLuint],
	['texture'],
)
glLightModelf=platform.createBaseFunction(
	'glLightModelf',platform.GL,None,
	[GLenum,GLfloat],
	['pname', 'param'],
)
glLightModelfv=platform.createBaseFunction(
	'glLightModelfv',platform.GL,None,
	[GLenum,GLfloatArray],
	['pname', 'params'],
)
glLightModeli=platform.createBaseFunction(
	'glLightModeli',platform.GL,None,
	[GLenum,GLint],
	['pname', 'param'],
)
glLightModeliv=platform.createBaseFunction(
	'glLightModeliv',platform.GL,None,
	[GLenum,GLintArray],
	['pname', 'params'],
)
glLightf=platform.createBaseFunction(
	'glLightf',platform.GL,None,
	[GLenum,GLenum,GLfloat],
	['light', 'pname', 'param'],
)
glLightfv=platform.createBaseFunction(
	'glLightfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['light', 'pname', 'params'],
)
glLighti=platform.createBaseFunction(
	'glLighti',platform.GL,None,
	[GLenum,GLenum,GLint],
	['light', 'pname', 'param'],
)
glLightiv=platform.createBaseFunction(
	'glLightiv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['light', 'pname', 'params'],
)
glLineStipple=platform.createBaseFunction(
	'glLineStipple',platform.GL,None,
	[GLint,GLushort],
	['factor', 'pattern'],
)
glLineWidth=platform.createBaseFunction(
	'glLineWidth',platform.GL,None,
	[GLfloat],
	['width'],
)
glListBase=platform.createBaseFunction(
	'glListBase',platform.GL,None,
	[GLuint],
	['base'],
)
glLoadIdentity=platform.createBaseFunction(
	'glLoadIdentity',platform.GL,None,
	[],
	[],
)
glLoadMatrixd=platform.createBaseFunction(
	'glLoadMatrixd',platform.GL,None,
	[GLdoubleArray],
	['m'],
)
glLoadMatrixf=platform.createBaseFunction(
	'glLoadMatrixf',platform.GL,None,
	[GLfloatArray],
	['m'],
)
glLoadName=platform.createBaseFunction(
	'glLoadName',platform.GL,None,
	[GLuint],
	['name'],
)
glLogicOp=platform.createBaseFunction(
	'glLogicOp',platform.GL,None,
	[GLenum],
	['opcode'],
)
glMap1d=platform.createBaseFunction(
	'glMap1d',platform.GL,None,
	[GLenum,GLdouble,GLdouble,GLint,GLint,GLdoubleArray],
	['target', 'u1', 'u2', 'stride', 'order', 'points'],
)
glMap1f=platform.createBaseFunction(
	'glMap1f',platform.GL,None,
	[GLenum,GLfloat,GLfloat,GLint,GLint,GLfloatArray],
	['target', 'u1', 'u2', 'stride', 'order', 'points'],
)
glMap2d=platform.createBaseFunction(
	'glMap2d',platform.GL,None,
	[GLenum,GLdouble,GLdouble,GLint,GLint,GLdouble,GLdouble,GLint,GLint,GLdoubleArray],
	['target', 'u1', 'u2', 'ustride', 'uorder', 'v1', 'v2', 'vstride', 'vorder', 'points'],
)
glMap2f=platform.createBaseFunction(
	'glMap2f',platform.GL,None,
	[GLenum,GLfloat,GLfloat,GLint,GLint,GLfloat,GLfloat,GLint,GLint,GLfloatArray],
	['target', 'u1', 'u2', 'ustride', 'uorder', 'v1', 'v2', 'vstride', 'vorder', 'points'],
)
glMapGrid1d=platform.createBaseFunction(
	'glMapGrid1d',platform.GL,None,
	[GLint,GLdouble,GLdouble],
	['un', 'u1', 'u2'],
)
glMapGrid1f=platform.createBaseFunction(
	'glMapGrid1f',platform.GL,None,
	[GLint,GLfloat,GLfloat],
	['un', 'u1', 'u2'],
)
glMapGrid2d=platform.createBaseFunction(
	'glMapGrid2d',platform.GL,None,
	[GLint,GLdouble,GLdouble,GLint,GLdouble,GLdouble],
	['un', 'u1', 'u2', 'vn', 'v1', 'v2'],
)
glMapGrid2f=platform.createBaseFunction(
	'glMapGrid2f',platform.GL,None,
	[GLint,GLfloat,GLfloat,GLint,GLfloat,GLfloat],
	['un', 'u1', 'u2', 'vn', 'v1', 'v2'],
)
glMaterialf=platform.createBaseFunction(
	'glMaterialf',platform.GL,None,
	[GLenum,GLenum,GLfloat],
	['face', 'pname', 'param'],
)
glMaterialfv=platform.createBaseFunction(
	'glMaterialfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['face', 'pname', 'params'],
)
glMateriali=platform.createBaseFunction(
	'glMateriali',platform.GL,None,
	[GLenum,GLenum,GLint],
	['face', 'pname', 'param'],
)
glMaterialiv=platform.createBaseFunction(
	'glMaterialiv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['face', 'pname', 'params'],
)
glMatrixMode=platform.createBaseFunction(
	'glMatrixMode',platform.GL,None,
	[GLenum],
	['mode'],
)
glMultMatrixd=platform.createBaseFunction(
	'glMultMatrixd',platform.GL,None,
	[GLdoubleArray],
	['m'],
)
glMultMatrixf=platform.createBaseFunction(
	'glMultMatrixf',platform.GL,None,
	[GLfloatArray],
	['m'],
)
glNewList=platform.createBaseFunction(
	'glNewList',platform.GL,None,
	[GLuint,GLenum],
	['list', 'mode'],
)
glNormal3b=platform.createBaseFunction(
	'glNormal3b',platform.GL,None,
	[GLbyte,GLbyte,GLbyte],
	['nx', 'ny', 'nz'],
)
glNormal3bv=platform.createBaseFunction(
	'glNormal3bv',platform.GL,None,
	[GLbyteArray],
	['v'],
)
glNormal3d=platform.createBaseFunction(
	'glNormal3d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['nx', 'ny', 'nz'],
)
glNormal3dv=platform.createBaseFunction(
	'glNormal3dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glNormal3f=platform.createBaseFunction(
	'glNormal3f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['nx', 'ny', 'nz'],
)
glNormal3fv=platform.createBaseFunction(
	'glNormal3fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glNormal3i=platform.createBaseFunction(
	'glNormal3i',platform.GL,None,
	[GLint,GLint,GLint],
	['nx', 'ny', 'nz'],
)
glNormal3iv=platform.createBaseFunction(
	'glNormal3iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glNormal3s=platform.createBaseFunction(
	'glNormal3s',platform.GL,None,
	[GLshort,GLshort,GLshort],
	['nx', 'ny', 'nz'],
)
glNormal3sv=platform.createBaseFunction(
	'glNormal3sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glNormalPointer=platform.createBaseFunction(
	'glNormalPointer',platform.GL,None,
	[GLenum,GLsizei,POINTER(GLvoid)],
	['type', 'stride', 'pointer'],
)
glOrtho=platform.createBaseFunction(
	'glOrtho',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble],
	['left', 'right', 'bottom', 'top', 'zNear', 'zFar'],
)
glPassThrough=platform.createBaseFunction(
	'glPassThrough',platform.GL,None,
	[GLfloat],
	['token'],
)
glPixelMapfv=platform.createBaseFunction(
	'glPixelMapfv',platform.GL,None,
	[GLenum,GLsizei,GLfloatArray],
	['map', 'mapsize', 'values'],
)
glPixelMapuiv=platform.createBaseFunction(
	'glPixelMapuiv',platform.GL,None,
	[GLenum,GLsizei,GLuintArray],
	['map', 'mapsize', 'values'],
)
glPixelMapusv=platform.createBaseFunction(
	'glPixelMapusv',platform.GL,None,
	[GLenum,GLsizei,GLushortArray],
	['map', 'mapsize', 'values'],
)
glPixelStoref=platform.createBaseFunction(
	'glPixelStoref',platform.GL,None,
	[GLenum,GLfloat],
	['pname', 'param'],
)
glPixelStorei=platform.createBaseFunction(
	'glPixelStorei',platform.GL,None,
	[GLenum,GLint],
	['pname', 'param'],
)
glPixelTransferf=platform.createBaseFunction(
	'glPixelTransferf',platform.GL,None,
	[GLenum,GLfloat],
	['pname', 'param'],
)
glPixelTransferi=platform.createBaseFunction(
	'glPixelTransferi',platform.GL,None,
	[GLenum,GLint],
	['pname', 'param'],
)
glPixelZoom=platform.createBaseFunction(
	'glPixelZoom',platform.GL,None,
	[GLfloat,GLfloat],
	['xfactor', 'yfactor'],
)
glPointSize=platform.createBaseFunction(
	'glPointSize',platform.GL,None,
	[GLfloat],
	['size'],
)
glPolygonMode=platform.createBaseFunction(
	'glPolygonMode',platform.GL,None,
	[GLenum,GLenum],
	['face', 'mode'],
)
glPolygonOffset=platform.createBaseFunction(
	'glPolygonOffset',platform.GL,None,
	[GLfloat,GLfloat],
	['factor', 'units'],
)
glPolygonStipple=platform.createBaseFunction(
	'glPolygonStipple',platform.GL,None,
	[GLubyteArray],
	['mask'],
)
glPopAttrib=platform.createBaseFunction(
	'glPopAttrib',platform.GL,None,
	[],
	[],
)
glPopClientAttrib=platform.createBaseFunction(
	'glPopClientAttrib',platform.GL,None,
	[],
	[],
)
glPopMatrix=platform.createBaseFunction(
	'glPopMatrix',platform.GL,None,
	[],
	[],
)
glPopName=platform.createBaseFunction(
	'glPopName',platform.GL,None,
	[],
	[],
)
glPrioritizeTextures=platform.createBaseFunction(
	'glPrioritizeTextures',platform.GL,None,
	[GLsizei,GLuintArray,GLclampfArray],
	['n', 'textures', 'priorities'],
)
glPushAttrib=platform.createBaseFunction(
	'glPushAttrib',platform.GL,None,
	[GLbitfield],
	['mask'],
)
glPushClientAttrib=platform.createBaseFunction(
	'glPushClientAttrib',platform.GL,None,
	[GLbitfield],
	['mask'],
)
glPushMatrix=platform.createBaseFunction(
	'glPushMatrix',platform.GL,None,
	[],
	[],
)
glPushName=platform.createBaseFunction(
	'glPushName',platform.GL,None,
	[GLuint],
	['name'],
)
glRasterPos2d=platform.createBaseFunction(
	'glRasterPos2d',platform.GL,None,
	[GLdouble,GLdouble],
	['x', 'y'],
)
glRasterPos2dv=platform.createBaseFunction(
	'glRasterPos2dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glRasterPos2f=platform.createBaseFunction(
	'glRasterPos2f',platform.GL,None,
	[GLfloat,GLfloat],
	['x', 'y'],
)
glRasterPos2fv=platform.createBaseFunction(
	'glRasterPos2fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glRasterPos2i=platform.createBaseFunction(
	'glRasterPos2i',platform.GL,None,
	[GLint,GLint],
	['x', 'y'],
)
glRasterPos2iv=platform.createBaseFunction(
	'glRasterPos2iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glRasterPos2s=platform.createBaseFunction(
	'glRasterPos2s',platform.GL,None,
	[GLshort,GLshort],
	['x', 'y'],
)
glRasterPos2sv=platform.createBaseFunction(
	'glRasterPos2sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glRasterPos3d=platform.createBaseFunction(
	'glRasterPos3d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z'],
)
glRasterPos3dv=platform.createBaseFunction(
	'glRasterPos3dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glRasterPos3f=platform.createBaseFunction(
	'glRasterPos3f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z'],
)
glRasterPos3fv=platform.createBaseFunction(
	'glRasterPos3fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glRasterPos3i=platform.createBaseFunction(
	'glRasterPos3i',platform.GL,None,
	[GLint,GLint,GLint],
	['x', 'y', 'z'],
)
glRasterPos3iv=platform.createBaseFunction(
	'glRasterPos3iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glRasterPos3s=platform.createBaseFunction(
	'glRasterPos3s',platform.GL,None,
	[GLshort,GLshort,GLshort],
	['x', 'y', 'z'],
)
glRasterPos3sv=platform.createBaseFunction(
	'glRasterPos3sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glRasterPos4d=platform.createBaseFunction(
	'glRasterPos4d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z', 'w'],
)
glRasterPos4dv=platform.createBaseFunction(
	'glRasterPos4dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glRasterPos4f=platform.createBaseFunction(
	'glRasterPos4f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z', 'w'],
)
glRasterPos4fv=platform.createBaseFunction(
	'glRasterPos4fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glRasterPos4i=platform.createBaseFunction(
	'glRasterPos4i',platform.GL,None,
	[GLint,GLint,GLint,GLint],
	['x', 'y', 'z', 'w'],
)
glRasterPos4iv=platform.createBaseFunction(
	'glRasterPos4iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glRasterPos4s=platform.createBaseFunction(
	'glRasterPos4s',platform.GL,None,
	[GLshort,GLshort,GLshort,GLshort],
	['x', 'y', 'z', 'w'],
)
glRasterPos4sv=platform.createBaseFunction(
	'glRasterPos4sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glReadBuffer=platform.createBaseFunction(
	'glReadBuffer',platform.GL,None,
	[GLenum],
	['mode'],
)
glReadPixels=platform.createBaseFunction(
	'glReadPixels',platform.GL,None,
	[GLint,GLint,GLsizei,GLsizei,GLenum,GLenum,POINTER(GLvoid)],
	['x', 'y', 'width', 'height', 'format', 'type', 'pixels'],
)
glRectd=platform.createBaseFunction(
	'glRectd',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['x1', 'y1', 'x2', 'y2'],
)
glRectdv=platform.createBaseFunction(
	'glRectdv',platform.GL,None,
	[GLdoubleArray,GLdoubleArray],
	['v1', 'v2'],
)
glRectf=platform.createBaseFunction(
	'glRectf',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['x1', 'y1', 'x2', 'y2'],
)
glRectfv=platform.createBaseFunction(
	'glRectfv',platform.GL,None,
	[GLfloatArray,GLfloatArray],
	['v1', 'v2'],
)
glRecti=platform.createBaseFunction(
	'glRecti',platform.GL,None,
	[GLint,GLint,GLint,GLint],
	['x1', 'y1', 'x2', 'y2'],
)
glRectiv=platform.createBaseFunction(
	'glRectiv',platform.GL,None,
	[GLintArray,GLintArray],
	['v1', 'v2'],
)
glRects=platform.createBaseFunction(
	'glRects',platform.GL,None,
	[GLshort,GLshort,GLshort,GLshort],
	['x1', 'y1', 'x2', 'y2'],
)
glRectsv=platform.createBaseFunction(
	'glRectsv',platform.GL,None,
	[GLshortArray,GLshortArray],
	['v1', 'v2'],
)
glRenderMode=platform.createBaseFunction(
	'glRenderMode',platform.GL,GLint,
	[GLenum],
	['mode'],
)
glRotated=platform.createBaseFunction(
	'glRotated',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['angle', 'x', 'y', 'z'],
)
glRotatef=platform.createBaseFunction(
	'glRotatef',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['angle', 'x', 'y', 'z'],
)
glScaled=platform.createBaseFunction(
	'glScaled',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z'],
)
glScalef=platform.createBaseFunction(
	'glScalef',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z'],
)
glScissor=platform.createBaseFunction(
	'glScissor',platform.GL,None,
	[GLint,GLint,GLsizei,GLsizei],
	['x', 'y', 'width', 'height'],
)
glSelectBuffer=platform.createBaseFunction(
	'glSelectBuffer',platform.GL,None,
	[GLsizei,GLuintArray],
	['size', 'buffer'],
)
glShadeModel=platform.createBaseFunction(
	'glShadeModel',platform.GL,None,
	[GLenum],
	['mode'],
)
glStencilFunc=platform.createBaseFunction(
	'glStencilFunc',platform.GL,None,
	[GLenum,GLint,GLuint],
	['func', 'ref', 'mask'],
)
glStencilMask=platform.createBaseFunction(
	'glStencilMask',platform.GL,None,
	[GLuint],
	['mask'],
)
glStencilOp=platform.createBaseFunction(
	'glStencilOp',platform.GL,None,
	[GLenum,GLenum,GLenum],
	['fail', 'zfail', 'zpass'],
)
glTexCoord1d=platform.createBaseFunction(
	'glTexCoord1d',platform.GL,None,
	[GLdouble],
	['s'],
)
glTexCoord1dv=platform.createBaseFunction(
	'glTexCoord1dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glTexCoord1f=platform.createBaseFunction(
	'glTexCoord1f',platform.GL,None,
	[GLfloat],
	['s'],
)
glTexCoord1fv=platform.createBaseFunction(
	'glTexCoord1fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glTexCoord1i=platform.createBaseFunction(
	'glTexCoord1i',platform.GL,None,
	[GLint],
	['s'],
)
glTexCoord1iv=platform.createBaseFunction(
	'glTexCoord1iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glTexCoord1s=platform.createBaseFunction(
	'glTexCoord1s',platform.GL,None,
	[GLshort],
	['s'],
)
glTexCoord1sv=platform.createBaseFunction(
	'glTexCoord1sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glTexCoord2d=platform.createBaseFunction(
	'glTexCoord2d',platform.GL,None,
	[GLdouble,GLdouble],
	['s', 't'],
)
glTexCoord2dv=platform.createBaseFunction(
	'glTexCoord2dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glTexCoord2f=platform.createBaseFunction(
	'glTexCoord2f',platform.GL,None,
	[GLfloat,GLfloat],
	['s', 't'],
)
glTexCoord2fv=platform.createBaseFunction(
	'glTexCoord2fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glTexCoord2i=platform.createBaseFunction(
	'glTexCoord2i',platform.GL,None,
	[GLint,GLint],
	['s', 't'],
)
glTexCoord2iv=platform.createBaseFunction(
	'glTexCoord2iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glTexCoord2s=platform.createBaseFunction(
	'glTexCoord2s',platform.GL,None,
	[GLshort,GLshort],
	['s', 't'],
)
glTexCoord2sv=platform.createBaseFunction(
	'glTexCoord2sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glTexCoord3d=platform.createBaseFunction(
	'glTexCoord3d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['s', 't', 'r'],
)
glTexCoord3dv=platform.createBaseFunction(
	'glTexCoord3dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glTexCoord3f=platform.createBaseFunction(
	'glTexCoord3f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['s', 't', 'r'],
)
glTexCoord3fv=platform.createBaseFunction(
	'glTexCoord3fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glTexCoord3i=platform.createBaseFunction(
	'glTexCoord3i',platform.GL,None,
	[GLint,GLint,GLint],
	['s', 't', 'r'],
)
glTexCoord3iv=platform.createBaseFunction(
	'glTexCoord3iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glTexCoord3s=platform.createBaseFunction(
	'glTexCoord3s',platform.GL,None,
	[GLshort,GLshort,GLshort],
	['s', 't', 'r'],
)
glTexCoord3sv=platform.createBaseFunction(
	'glTexCoord3sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glTexCoord4d=platform.createBaseFunction(
	'glTexCoord4d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['s', 't', 'r', 'q'],
)
glTexCoord4dv=platform.createBaseFunction(
	'glTexCoord4dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glTexCoord4f=platform.createBaseFunction(
	'glTexCoord4f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['s', 't', 'r', 'q'],
)
glTexCoord4fv=platform.createBaseFunction(
	'glTexCoord4fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glTexCoord4i=platform.createBaseFunction(
	'glTexCoord4i',platform.GL,None,
	[GLint,GLint,GLint,GLint],
	['s', 't', 'r', 'q'],
)
glTexCoord4iv=platform.createBaseFunction(
	'glTexCoord4iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glTexCoord4s=platform.createBaseFunction(
	'glTexCoord4s',platform.GL,None,
	[GLshort,GLshort,GLshort,GLshort],
	['s', 't', 'r', 'q'],
)
glTexCoord4sv=platform.createBaseFunction(
	'glTexCoord4sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glTexCoordPointer=platform.createBaseFunction(
	'glTexCoordPointer',platform.GL,None,
	[GLint,GLenum,GLsizei,POINTER(GLvoid)],
	['size', 'type', 'stride', 'pointer'],
)
glTexEnvf=platform.createBaseFunction(
	'glTexEnvf',platform.GL,None,
	[GLenum,GLenum,GLfloat],
	['target', 'pname', 'param'],
)
glTexEnvfv=platform.createBaseFunction(
	'glTexEnvfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['target', 'pname', 'params'],
)
glTexEnvi=platform.createBaseFunction(
	'glTexEnvi',platform.GL,None,
	[GLenum,GLenum,GLint],
	['target', 'pname', 'param'],
)
glTexEnviv=platform.createBaseFunction(
	'glTexEnviv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['target', 'pname', 'params'],
)
glTexGend=platform.createBaseFunction(
	'glTexGend',platform.GL,None,
	[GLenum,GLenum,GLdouble],
	['coord', 'pname', 'param'],
)
glTexGendv=platform.createBaseFunction(
	'glTexGendv',platform.GL,None,
	[GLenum,GLenum,GLdoubleArray],
	['coord', 'pname', 'params'],
)
glTexGenf=platform.createBaseFunction(
	'glTexGenf',platform.GL,None,
	[GLenum,GLenum,GLfloat],
	['coord', 'pname', 'param'],
)
glTexGenfv=platform.createBaseFunction(
	'glTexGenfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['coord', 'pname', 'params'],
)
glTexGeni=platform.createBaseFunction(
	'glTexGeni',platform.GL,None,
	[GLenum,GLenum,GLint],
	['coord', 'pname', 'param'],
)
glTexGeniv=platform.createBaseFunction(
	'glTexGeniv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['coord', 'pname', 'params'],
)
glTexImage1D=platform.createBaseFunction(
	'glTexImage1D',platform.GL,None,
	[GLenum,GLint,GLint,GLsizei,GLint,GLenum,GLenum,POINTER(GLvoid)],
	['target', 'level', 'internalformat', 'width', 'border', 'format', 'type', 'pixels'],
)
glTexImage2D=platform.createBaseFunction(
	'glTexImage2D',platform.GL,None,
	[GLenum,GLint,GLint,GLsizei,GLsizei,GLint,GLenum,GLenum,POINTER(GLvoid)],
	['target', 'level', 'internalformat', 'width', 'height', 'border', 'format', 'type', 'pixels'],
)
glTexParameterf=platform.createBaseFunction(
	'glTexParameterf',platform.GL,None,
	[GLenum,GLenum,GLfloat],
	['target', 'pname', 'param'],
)
glTexParameterfv=platform.createBaseFunction(
	'glTexParameterfv',platform.GL,None,
	[GLenum,GLenum,GLfloatArray],
	['target', 'pname', 'params'],
)
glTexParameteri=platform.createBaseFunction(
	'glTexParameteri',platform.GL,None,
	[GLenum,GLenum,GLint],
	['target', 'pname', 'param'],
)
glTexParameteriv=platform.createBaseFunction(
	'glTexParameteriv',platform.GL,None,
	[GLenum,GLenum,GLintArray],
	['target', 'pname', 'params'],
)
glTexSubImage1D=platform.createBaseFunction(
	'glTexSubImage1D',platform.GL,None,
	[GLenum,GLint,GLint,GLsizei,GLenum,GLenum,POINTER(GLvoid)],
	['target', 'level', 'xoffset', 'width', 'format', 'type', 'pixels'],
)
glTexSubImage2D=platform.createBaseFunction(
	'glTexSubImage2D',platform.GL,None,
	[GLenum,GLint,GLint,GLint,GLsizei,GLsizei,GLenum,GLenum,POINTER(GLvoid)],
	['target', 'level', 'xoffset', 'yoffset', 'width', 'height', 'format', 'type', 'pixels'],
)
glTranslated=platform.createBaseFunction(
	'glTranslated',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z'],
)
glTranslatef=platform.createBaseFunction(
	'glTranslatef',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z'],
)
glVertex2d=platform.createBaseFunction(
	'glVertex2d',platform.GL,None,
	[GLdouble,GLdouble],
	['x', 'y'],
)
glVertex2dv=platform.createBaseFunction(
	'glVertex2dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glVertex2f=platform.createBaseFunction(
	'glVertex2f',platform.GL,None,
	[GLfloat,GLfloat],
	['x', 'y'],
)
glVertex2fv=platform.createBaseFunction(
	'glVertex2fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glVertex2i=platform.createBaseFunction(
	'glVertex2i',platform.GL,None,
	[GLint,GLint],
	['x', 'y'],
)
glVertex2iv=platform.createBaseFunction(
	'glVertex2iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glVertex2s=platform.createBaseFunction(
	'glVertex2s',platform.GL,None,
	[GLshort,GLshort],
	['x', 'y'],
)
glVertex2sv=platform.createBaseFunction(
	'glVertex2sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glVertex3d=platform.createBaseFunction(
	'glVertex3d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z'],
)
glVertex3dv=platform.createBaseFunction(
	'glVertex3dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glVertex3f=platform.createBaseFunction(
	'glVertex3f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z'],
)
glVertex3fv=platform.createBaseFunction(
	'glVertex3fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glVertex3i=platform.createBaseFunction(
	'glVertex3i',platform.GL,None,
	[GLint,GLint,GLint],
	['x', 'y', 'z'],
)
glVertex3iv=platform.createBaseFunction(
	'glVertex3iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glVertex3s=platform.createBaseFunction(
	'glVertex3s',platform.GL,None,
	[GLshort,GLshort,GLshort],
	['x', 'y', 'z'],
)
glVertex3sv=platform.createBaseFunction(
	'glVertex3sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glVertex4d=platform.createBaseFunction(
	'glVertex4d',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['x', 'y', 'z', 'w'],
)
glVertex4dv=platform.createBaseFunction(
	'glVertex4dv',platform.GL,None,
	[GLdoubleArray],
	['v'],
)
glVertex4f=platform.createBaseFunction(
	'glVertex4f',platform.GL,None,
	[GLfloat,GLfloat,GLfloat,GLfloat],
	['x', 'y', 'z', 'w'],
)
glVertex4fv=platform.createBaseFunction(
	'glVertex4fv',platform.GL,None,
	[GLfloatArray],
	['v'],
)
glVertex4i=platform.createBaseFunction(
	'glVertex4i',platform.GL,None,
	[GLint,GLint,GLint,GLint],
	['x', 'y', 'z', 'w'],
)
glVertex4iv=platform.createBaseFunction(
	'glVertex4iv',platform.GL,None,
	[GLintArray],
	['v'],
)
glVertex4s=platform.createBaseFunction(
	'glVertex4s',platform.GL,None,
	[GLshort,GLshort,GLshort,GLshort],
	['x', 'y', 'z', 'w'],
)
glVertex4sv=platform.createBaseFunction(
	'glVertex4sv',platform.GL,None,
	[GLshortArray],
	['v'],
)
glVertexPointer=platform.createBaseFunction(
	'glVertexPointer',platform.GL,None,
	[GLint,GLenum,GLsizei,POINTER(GLvoid)],
	['size', 'type', 'stride', 'pointer'],
)
glViewport=platform.createBaseFunction(
	'glViewport',platform.GL,None,
	[GLint,GLint,GLsizei,GLsizei],
	['x', 'y', 'width', 'height'],
)

__all__ = ['GL_VERSION_1_1', 'GL_CURRENT_BIT', 'GL_POINT_BIT', 'GL_LINE_BIT',
'GL_POLYGON_BIT', 'GL_POLYGON_STIPPLE_BIT', 'GL_PIXEL_MODE_BIT',
'GL_LIGHTING_BIT', 'GL_FOG_BIT', 'GL_DEPTH_BUFFER_BIT', 'GL_ACCUM_BUFFER_BIT',
'GL_STENCIL_BUFFER_BIT', 'GL_VIEWPORT_BIT', 'GL_TRANSFORM_BIT',
'GL_ENABLE_BIT', 'GL_COLOR_BUFFER_BIT', 'GL_HINT_BIT', 'GL_EVAL_BIT',
'GL_LIST_BIT', 'GL_TEXTURE_BIT', 'GL_SCISSOR_BIT', 'GL_ALL_ATTRIB_BITS',
'GL_CLIENT_PIXEL_STORE_BIT', 'GL_CLIENT_VERTEX_ARRAY_BIT',
'GL_CLIENT_ALL_ATTRIB_BITS', 'GL_FALSE', 'GL_TRUE', 'GL_POINTS', 'GL_LINES',
'GL_LINE_LOOP', 'GL_LINE_STRIP', 'GL_TRIANGLES', 'GL_TRIANGLE_STRIP',
'GL_TRIANGLE_FAN', 'GL_QUADS', 'GL_QUAD_STRIP', 'GL_POLYGON', 'GL_ACCUM',
'GL_LOAD', 'GL_RETURN', 'GL_MULT', 'GL_ADD', 'GL_NEVER', 'GL_LESS',
'GL_EQUAL', 'GL_LEQUAL', 'GL_GREATER', 'GL_NOTEQUAL', 'GL_GEQUAL',
'GL_ALWAYS', 'GL_ZERO', 'GL_ONE', 'GL_SRC_COLOR', 'GL_ONE_MINUS_SRC_COLOR',
'GL_SRC_ALPHA', 'GL_ONE_MINUS_SRC_ALPHA', 'GL_DST_ALPHA',
'GL_ONE_MINUS_DST_ALPHA', 'GL_DST_COLOR', 'GL_ONE_MINUS_DST_COLOR',
'GL_SRC_ALPHA_SATURATE', 'GL_NONE', 'GL_FRONT_LEFT', 'GL_FRONT_RIGHT',
'GL_BACK_LEFT', 'GL_BACK_RIGHT', 'GL_FRONT', 'GL_BACK', 'GL_LEFT', 'GL_RIGHT',
'GL_FRONT_AND_BACK', 'GL_AUX0', 'GL_AUX1', 'GL_AUX2', 'GL_AUX3',
'GL_NO_ERROR', 'GL_INVALID_ENUM', 'GL_INVALID_VALUE', 'GL_INVALID_OPERATION',
'GL_STACK_OVERFLOW', 'GL_STACK_UNDERFLOW', 'GL_OUT_OF_MEMORY',
'GL_TABLE_TOO_LARGE', 'GL_2D', 'GL_3D', 'GL_3D_COLOR', 'GL_3D_COLOR_TEXTURE',
'GL_4D_COLOR_TEXTURE', 'GL_PASS_THROUGH_TOKEN', 'GL_POINT_TOKEN',
'GL_LINE_TOKEN', 'GL_POLYGON_TOKEN', 'GL_BITMAP_TOKEN', 'GL_DRAW_PIXEL_TOKEN',
'GL_COPY_PIXEL_TOKEN', 'GL_LINE_RESET_TOKEN', 'GL_EXP', 'GL_EXP2', 'GL_CW',
'GL_CCW', 'GL_COEFF', 'GL_ORDER', 'GL_DOMAIN', 'GL_PIXEL_MAP_I_TO_I',
'GL_PIXEL_MAP_S_TO_S', 'GL_PIXEL_MAP_I_TO_R', 'GL_PIXEL_MAP_I_TO_G',
'GL_PIXEL_MAP_I_TO_B', 'GL_PIXEL_MAP_I_TO_A', 'GL_PIXEL_MAP_R_TO_R',
'GL_PIXEL_MAP_G_TO_G', 'GL_PIXEL_MAP_B_TO_B', 'GL_PIXEL_MAP_A_TO_A',
'GL_VERTEX_ARRAY_POINTER', 'GL_NORMAL_ARRAY_POINTER',
'GL_COLOR_ARRAY_POINTER', 'GL_INDEX_ARRAY_POINTER',
'GL_TEXTURE_COORD_ARRAY_POINTER', 'GL_EDGE_FLAG_ARRAY_POINTER',
'GL_CURRENT_COLOR', 'GL_CURRENT_INDEX', 'GL_CURRENT_NORMAL',
'GL_CURRENT_TEXTURE_COORDS', 'GL_CURRENT_RASTER_COLOR',
'GL_CURRENT_RASTER_INDEX', 'GL_CURRENT_RASTER_TEXTURE_COORDS',
'GL_CURRENT_RASTER_POSITION', 'GL_CURRENT_RASTER_POSITION_VALID',
'GL_CURRENT_RASTER_DISTANCE', 'GL_POINT_SMOOTH', 'GL_POINT_SIZE',
'GL_SMOOTH_POINT_SIZE_RANGE', 'GL_SMOOTH_POINT_SIZE_GRANULARITY',
'GL_POINT_SIZE_RANGE', 'GL_POINT_SIZE_GRANULARITY', 'GL_LINE_SMOOTH',
'GL_LINE_WIDTH', 'GL_SMOOTH_LINE_WIDTH_RANGE',
'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 'GL_LINE_WIDTH_RANGE',
'GL_LINE_WIDTH_GRANULARITY', 'GL_LINE_STIPPLE', 'GL_LINE_STIPPLE_PATTERN',
'GL_LINE_STIPPLE_REPEAT', 'GL_LIST_MODE', 'GL_MAX_LIST_NESTING',
'GL_LIST_BASE', 'GL_LIST_INDEX', 'GL_POLYGON_MODE', 'GL_POLYGON_SMOOTH',
'GL_POLYGON_STIPPLE', 'GL_EDGE_FLAG', 'GL_CULL_FACE', 'GL_CULL_FACE_MODE',
'GL_FRONT_FACE', 'GL_LIGHTING', 'GL_LIGHT_MODEL_LOCAL_VIEWER',
'GL_LIGHT_MODEL_TWO_SIDE', 'GL_LIGHT_MODEL_AMBIENT', 'GL_SHADE_MODEL',
'GL_COLOR_MATERIAL_FACE', 'GL_COLOR_MATERIAL_PARAMETER', 'GL_COLOR_MATERIAL',
'GL_FOG', 'GL_FOG_INDEX', 'GL_FOG_DENSITY', 'GL_FOG_START', 'GL_FOG_END',
'GL_FOG_MODE', 'GL_FOG_COLOR', 'GL_DEPTH_RANGE', 'GL_DEPTH_TEST',
'GL_DEPTH_WRITEMASK', 'GL_DEPTH_CLEAR_VALUE', 'GL_DEPTH_FUNC',
'GL_ACCUM_CLEAR_VALUE', 'GL_STENCIL_TEST', 'GL_STENCIL_CLEAR_VALUE',
'GL_STENCIL_FUNC', 'GL_STENCIL_VALUE_MASK', 'GL_STENCIL_FAIL',
'GL_STENCIL_PASS_DEPTH_FAIL', 'GL_STENCIL_PASS_DEPTH_PASS', 'GL_STENCIL_REF',
'GL_STENCIL_WRITEMASK', 'GL_MATRIX_MODE', 'GL_NORMALIZE', 'GL_VIEWPORT',
'GL_MODELVIEW_STACK_DEPTH', 'GL_PROJECTION_STACK_DEPTH',
'GL_TEXTURE_STACK_DEPTH', 'GL_MODELVIEW_MATRIX', 'GL_PROJECTION_MATRIX',
'GL_TEXTURE_MATRIX', 'GL_ATTRIB_STACK_DEPTH', 'GL_CLIENT_ATTRIB_STACK_DEPTH',
'GL_ALPHA_TEST', 'GL_ALPHA_TEST_FUNC', 'GL_ALPHA_TEST_REF', 'GL_DITHER',
'GL_BLEND_DST', 'GL_BLEND_SRC', 'GL_BLEND', 'GL_LOGIC_OP_MODE',
'GL_INDEX_LOGIC_OP', 'GL_LOGIC_OP', 'GL_COLOR_LOGIC_OP', 'GL_AUX_BUFFERS',
'GL_DRAW_BUFFER', 'GL_READ_BUFFER', 'GL_SCISSOR_BOX', 'GL_SCISSOR_TEST',
'GL_INDEX_CLEAR_VALUE', 'GL_INDEX_WRITEMASK', 'GL_COLOR_CLEAR_VALUE',
'GL_COLOR_WRITEMASK', 'GL_INDEX_MODE', 'GL_RGBA_MODE', 'GL_DOUBLEBUFFER',
'GL_STEREO', 'GL_RENDER_MODE', 'GL_PERSPECTIVE_CORRECTION_HINT',
'GL_POINT_SMOOTH_HINT', 'GL_LINE_SMOOTH_HINT', 'GL_POLYGON_SMOOTH_HINT',
'GL_FOG_HINT', 'GL_TEXTURE_GEN_S', 'GL_TEXTURE_GEN_T', 'GL_TEXTURE_GEN_R',
'GL_TEXTURE_GEN_Q', 'GL_PIXEL_MAP_I_TO_I_SIZE', 'GL_PIXEL_MAP_S_TO_S_SIZE',
'GL_PIXEL_MAP_I_TO_R_SIZE', 'GL_PIXEL_MAP_I_TO_G_SIZE',
'GL_PIXEL_MAP_I_TO_B_SIZE', 'GL_PIXEL_MAP_I_TO_A_SIZE',
'GL_PIXEL_MAP_R_TO_R_SIZE', 'GL_PIXEL_MAP_G_TO_G_SIZE',
'GL_PIXEL_MAP_B_TO_B_SIZE', 'GL_PIXEL_MAP_A_TO_A_SIZE',
'GL_UNPACK_SWAP_BYTES', 'GL_UNPACK_LSB_FIRST', 'GL_UNPACK_ROW_LENGTH',
'GL_UNPACK_SKIP_ROWS', 'GL_UNPACK_SKIP_PIXELS', 'GL_UNPACK_ALIGNMENT',
'GL_PACK_SWAP_BYTES', 'GL_PACK_LSB_FIRST', 'GL_PACK_ROW_LENGTH',
'GL_PACK_SKIP_ROWS', 'GL_PACK_SKIP_PIXELS', 'GL_PACK_ALIGNMENT',
'GL_MAP_COLOR', 'GL_MAP_STENCIL', 'GL_INDEX_SHIFT', 'GL_INDEX_OFFSET',
'GL_RED_SCALE', 'GL_RED_BIAS', 'GL_ZOOM_X', 'GL_ZOOM_Y', 'GL_GREEN_SCALE',
'GL_GREEN_BIAS', 'GL_BLUE_SCALE', 'GL_BLUE_BIAS', 'GL_ALPHA_SCALE',
'GL_ALPHA_BIAS', 'GL_DEPTH_SCALE', 'GL_DEPTH_BIAS', 'GL_MAX_EVAL_ORDER',
'GL_MAX_LIGHTS', 'GL_MAX_CLIP_PLANES', 'GL_MAX_TEXTURE_SIZE',
'GL_MAX_PIXEL_MAP_TABLE', 'GL_MAX_ATTRIB_STACK_DEPTH',
'GL_MAX_MODELVIEW_STACK_DEPTH', 'GL_MAX_NAME_STACK_DEPTH',
'GL_MAX_PROJECTION_STACK_DEPTH', 'GL_MAX_TEXTURE_STACK_DEPTH',
'GL_MAX_VIEWPORT_DIMS', 'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH',
'GL_SUBPIXEL_BITS', 'GL_INDEX_BITS', 'GL_RED_BITS', 'GL_GREEN_BITS',
'GL_BLUE_BITS', 'GL_ALPHA_BITS', 'GL_DEPTH_BITS', 'GL_STENCIL_BITS',
'GL_ACCUM_RED_BITS', 'GL_ACCUM_GREEN_BITS', 'GL_ACCUM_BLUE_BITS',
'GL_ACCUM_ALPHA_BITS', 'GL_NAME_STACK_DEPTH', 'GL_AUTO_NORMAL',
'GL_MAP1_COLOR_4', 'GL_MAP1_INDEX', 'GL_MAP1_NORMAL',
'GL_MAP1_TEXTURE_COORD_1', 'GL_MAP1_TEXTURE_COORD_2',
'GL_MAP1_TEXTURE_COORD_3', 'GL_MAP1_TEXTURE_COORD_4', 'GL_MAP1_VERTEX_3',
'GL_MAP1_VERTEX_4', 'GL_MAP2_COLOR_4', 'GL_MAP2_INDEX', 'GL_MAP2_NORMAL',
'GL_MAP2_TEXTURE_COORD_1', 'GL_MAP2_TEXTURE_COORD_2',
'GL_MAP2_TEXTURE_COORD_3', 'GL_MAP2_TEXTURE_COORD_4', 'GL_MAP2_VERTEX_3',
'GL_MAP2_VERTEX_4', 'GL_MAP1_GRID_DOMAIN', 'GL_MAP1_GRID_SEGMENTS',
'GL_MAP2_GRID_DOMAIN', 'GL_MAP2_GRID_SEGMENTS', 'GL_TEXTURE_1D',
'GL_TEXTURE_2D', 'GL_FEEDBACK_BUFFER_POINTER', 'GL_FEEDBACK_BUFFER_SIZE',
'GL_FEEDBACK_BUFFER_TYPE', 'GL_SELECTION_BUFFER_POINTER',
'GL_SELECTION_BUFFER_SIZE', 'GL_POLYGON_OFFSET_UNITS',
'GL_POLYGON_OFFSET_POINT', 'GL_POLYGON_OFFSET_LINE', 'GL_POLYGON_OFFSET_FILL',
'GL_POLYGON_OFFSET_FACTOR', 'GL_TEXTURE_BINDING_1D', 'GL_TEXTURE_BINDING_2D',
'GL_TEXTURE_BINDING_3D', 'GL_VERTEX_ARRAY', 'GL_NORMAL_ARRAY',
'GL_COLOR_ARRAY', 'GL_INDEX_ARRAY', 'GL_TEXTURE_COORD_ARRAY',
'GL_EDGE_FLAG_ARRAY', 'GL_VERTEX_ARRAY_SIZE', 'GL_VERTEX_ARRAY_TYPE',
'GL_VERTEX_ARRAY_STRIDE', 'GL_NORMAL_ARRAY_TYPE', 'GL_NORMAL_ARRAY_STRIDE',
'GL_COLOR_ARRAY_SIZE', 'GL_COLOR_ARRAY_TYPE', 'GL_COLOR_ARRAY_STRIDE',
'GL_INDEX_ARRAY_TYPE', 'GL_INDEX_ARRAY_STRIDE', 'GL_TEXTURE_COORD_ARRAY_SIZE',
'GL_TEXTURE_COORD_ARRAY_TYPE', 'GL_TEXTURE_COORD_ARRAY_STRIDE',
'GL_EDGE_FLAG_ARRAY_STRIDE', 'GL_TEXTURE_WIDTH', 'GL_TEXTURE_HEIGHT',
'GL_TEXTURE_INTERNAL_FORMAT', 'GL_TEXTURE_COMPONENTS',
'GL_TEXTURE_BORDER_COLOR', 'GL_TEXTURE_BORDER', 'GL_TEXTURE_RED_SIZE',
'GL_TEXTURE_GREEN_SIZE', 'GL_TEXTURE_BLUE_SIZE', 'GL_TEXTURE_ALPHA_SIZE',
'GL_TEXTURE_LUMINANCE_SIZE', 'GL_TEXTURE_INTENSITY_SIZE',
'GL_TEXTURE_PRIORITY', 'GL_TEXTURE_RESIDENT', 'GL_DONT_CARE', 'GL_FASTEST',
'GL_NICEST', 'GL_AMBIENT', 'GL_DIFFUSE', 'GL_SPECULAR', 'GL_POSITION',
'GL_SPOT_DIRECTION', 'GL_SPOT_EXPONENT', 'GL_SPOT_CUTOFF',
'GL_CONSTANT_ATTENUATION', 'GL_LINEAR_ATTENUATION',
'GL_QUADRATIC_ATTENUATION', 'GL_COMPILE', 'GL_COMPILE_AND_EXECUTE', 'GL_BYTE',
'GL_UNSIGNED_BYTE', 'GL_SHORT', 'GL_UNSIGNED_SHORT', 'GL_INT',
'GL_UNSIGNED_INT', 'GL_FLOAT', 'GL_2_BYTES', 'GL_3_BYTES', 'GL_4_BYTES',
'GL_DOUBLE', 'GL_DOUBLE_EXT', 'GL_CLEAR', 'GL_AND', 'GL_AND_REVERSE',
'GL_COPY', 'GL_AND_INVERTED', 'GL_NOOP', 'GL_XOR', 'GL_OR', 'GL_NOR',
'GL_EQUIV', 'GL_INVERT', 'GL_OR_REVERSE', 'GL_COPY_INVERTED',
'GL_OR_INVERTED', 'GL_NAND', 'GL_SET', 'GL_EMISSION', 'GL_SHININESS',
'GL_AMBIENT_AND_DIFFUSE', 'GL_COLOR_INDEXES', 'GL_MODELVIEW', 'GL_PROJECTION',
'GL_TEXTURE', 'GL_COLOR', 'GL_DEPTH', 'GL_STENCIL', 'GL_COLOR_INDEX',
'GL_STENCIL_INDEX', 'GL_DEPTH_COMPONENT', 'GL_RED', 'GL_GREEN', 'GL_BLUE',
'GL_ALPHA', 'GL_RGB', 'GL_RGBA', 'GL_LUMINANCE', 'GL_LUMINANCE_ALPHA',
'GL_BITMAP', 'GL_POINT', 'GL_LINE', 'GL_FILL', 'GL_RENDER', 'GL_FEEDBACK',
'GL_SELECT', 'GL_FLAT', 'GL_SMOOTH', 'GL_KEEP', 'GL_REPLACE', 'GL_INCR',
'GL_DECR', 'GL_VENDOR', 'GL_RENDERER', 'GL_VERSION', 'GL_EXTENSIONS', 'GL_S',
'GL_T', 'GL_R', 'GL_Q', 'GL_MODULATE', 'GL_DECAL', 'GL_TEXTURE_ENV_MODE',
'GL_TEXTURE_ENV_COLOR', 'GL_TEXTURE_ENV', 'GL_EYE_LINEAR', 'GL_OBJECT_LINEAR',
'GL_SPHERE_MAP', 'GL_TEXTURE_GEN_MODE', 'GL_OBJECT_PLANE', 'GL_EYE_PLANE',
'GL_NEAREST', 'GL_LINEAR', 'GL_NEAREST_MIPMAP_NEAREST',
'GL_LINEAR_MIPMAP_NEAREST', 'GL_NEAREST_MIPMAP_LINEAR',
'GL_LINEAR_MIPMAP_LINEAR', 'GL_TEXTURE_MAG_FILTER', 'GL_TEXTURE_MIN_FILTER',
'GL_TEXTURE_WRAP_S', 'GL_TEXTURE_WRAP_T', 'GL_PROXY_TEXTURE_1D',
'GL_PROXY_TEXTURE_2D', 'GL_CLAMP', 'GL_REPEAT', 'GL_R3_G3_B2', 'GL_ALPHA4',
'GL_ALPHA8', 'GL_ALPHA12', 'GL_ALPHA16', 'GL_LUMINANCE4', 'GL_LUMINANCE8',
'GL_LUMINANCE12', 'GL_LUMINANCE16', 'GL_LUMINANCE4_ALPHA4',
'GL_LUMINANCE6_ALPHA2', 'GL_LUMINANCE8_ALPHA8', 'GL_LUMINANCE12_ALPHA4',
'GL_LUMINANCE12_ALPHA12', 'GL_LUMINANCE16_ALPHA16', 'GL_INTENSITY',
'GL_INTENSITY4', 'GL_INTENSITY8', 'GL_INTENSITY12', 'GL_INTENSITY16',
'GL_RGB4', 'GL_RGB5', 'GL_RGB8', 'GL_RGB10', 'GL_RGB12', 'GL_RGB16',
'GL_RGBA2', 'GL_RGBA4', 'GL_RGB5_A1', 'GL_RGBA8', 'GL_RGB10_A2', 'GL_RGBA12',
'GL_RGBA16', 'GL_V2F', 'GL_V3F', 'GL_C4UB_V2F', 'GL_C4UB_V3F', 'GL_C3F_V3F',
'GL_N3F_V3F', 'GL_C4F_N3F_V3F', 'GL_T2F_V3F', 'GL_T4F_V4F', 'GL_T2F_C4UB_V3F',
'GL_T2F_C3F_V3F', 'GL_T2F_N3F_V3F', 'GL_T2F_C4F_N3F_V3F',
'GL_T4F_C4F_N3F_V4F', 'GL_CLIP_PLANE0', 'GL_CLIP_PLANE1', 'GL_CLIP_PLANE2',
'GL_CLIP_PLANE3', 'GL_CLIP_PLANE4', 'GL_CLIP_PLANE5', 'GL_LIGHT0',
'GL_LIGHT1', 'GL_LIGHT2', 'GL_LIGHT3', 'GL_LIGHT4', 'GL_LIGHT5', 'GL_LIGHT6',
'GL_LIGHT7', 'GL_ABGR_EXT', 'GL_FUNC_SUBTRACT_EXT',
'GL_FUNC_REVERSE_SUBTRACT_EXT', 'GL_UNSIGNED_BYTE_3_3_2_EXT',
'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 'GL_UNSIGNED_SHORT_5_5_5_1_EXT',
'GL_UNSIGNED_INT_8_8_8_8_EXT', 'GL_UNSIGNED_INT_10_10_10_2_EXT',
'GL_PACK_SKIP_IMAGES', 'GL_PACK_IMAGE_HEIGHT', 'GL_UNPACK_SKIP_IMAGES',
'GL_UNPACK_IMAGE_HEIGHT', 'GL_TEXTURE_3D', 'GL_PROXY_TEXTURE_3D',
'GL_TEXTURE_DEPTH', 'GL_TEXTURE_WRAP_R', 'GL_MAX_3D_TEXTURE_SIZE', 'GL_BGR',
'GL_BGRA', 'GL_UNSIGNED_BYTE_3_3_2', 'GL_UNSIGNED_BYTE_2_3_3_REV',
'GL_UNSIGNED_SHORT_5_6_5', 'GL_UNSIGNED_SHORT_5_6_5_REV',
'GL_UNSIGNED_SHORT_4_4_4_4', 'GL_UNSIGNED_SHORT_4_4_4_4_REV',
'GL_UNSIGNED_SHORT_5_5_5_1', 'GL_UNSIGNED_SHORT_1_5_5_5_REV',
'GL_UNSIGNED_INT_8_8_8_8', 'GL_UNSIGNED_INT_8_8_8_8_REV',
'GL_UNSIGNED_INT_10_10_10_2', 'GL_UNSIGNED_INT_2_10_10_10_REV',
'GL_RESCALE_NORMAL', 'GL_LIGHT_MODEL_COLOR_CONTROL', 'GL_SINGLE_COLOR',
'GL_SEPARATE_SPECULAR_COLOR', 'GL_CLAMP_TO_EDGE', 'GL_TEXTURE_MIN_LOD',
'GL_TEXTURE_MAX_LOD', 'GL_TEXTURE_BASE_LEVEL', 'GL_TEXTURE_MAX_LEVEL',
'GL_MAX_ELEMENTS_VERTICES', 'GL_MAX_ELEMENTS_INDICES',
'GL_ALIASED_POINT_SIZE_RANGE', 'GL_ALIASED_LINE_WIDTH_RANGE',
'GL_ACTIVE_TEXTURE', 'GL_CLIENT_ACTIVE_TEXTURE', 'GL_MAX_TEXTURE_UNITS',
'GL_TEXTURE0', 'GL_TEXTURE1', 'GL_TEXTURE2', 'GL_TEXTURE3', 'GL_TEXTURE4',
'GL_TEXTURE5', 'GL_TEXTURE6', 'GL_TEXTURE7', 'GL_TEXTURE8', 'GL_TEXTURE9',
'GL_TEXTURE10', 'GL_TEXTURE11', 'GL_TEXTURE12', 'GL_TEXTURE13',
'GL_TEXTURE14', 'GL_TEXTURE15', 'GL_TEXTURE16', 'GL_TEXTURE17',
'GL_TEXTURE18', 'GL_TEXTURE19', 'GL_TEXTURE20', 'GL_TEXTURE21',
'GL_TEXTURE22', 'GL_TEXTURE23', 'GL_TEXTURE24', 'GL_TEXTURE25',
'GL_TEXTURE26', 'GL_TEXTURE27', 'GL_TEXTURE28', 'GL_TEXTURE29',
'GL_TEXTURE30', 'GL_TEXTURE31', 'GL_NORMAL_MAP', 'GL_REFLECTION_MAP',
'GL_TEXTURE_CUBE_MAP', 'GL_TEXTURE_BINDING_CUBE_MAP',
'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z',
'GL_PROXY_TEXTURE_CUBE_MAP', 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 'GL_COMBINE',
'GL_COMBINE_RGB', 'GL_COMBINE_ALPHA', 'GL_RGB_SCALE', 'GL_ADD_SIGNED',
'GL_INTERPOLATE', 'GL_CONSTANT', 'GL_PRIMARY_COLOR', 'GL_PREVIOUS',
'GL_SOURCE0_RGB', 'GL_SOURCE1_RGB', 'GL_SOURCE2_RGB', 'GL_SOURCE0_ALPHA',
'GL_SOURCE1_ALPHA', 'GL_SOURCE2_ALPHA', 'GL_OPERAND0_RGB', 'GL_OPERAND1_RGB',
'GL_OPERAND2_RGB', 'GL_OPERAND0_ALPHA', 'GL_OPERAND1_ALPHA',
'GL_OPERAND2_ALPHA', 'GL_SUBTRACT', 'GL_TRANSPOSE_MODELVIEW_MATRIX',
'GL_TRANSPOSE_PROJECTION_MATRIX', 'GL_TRANSPOSE_TEXTURE_MATRIX',
'GL_TRANSPOSE_COLOR_MATRIX', 'GL_COMPRESSED_ALPHA', 'GL_COMPRESSED_LUMINANCE',
'GL_COMPRESSED_LUMINANCE_ALPHA', 'GL_COMPRESSED_INTENSITY',
'GL_COMPRESSED_RGB', 'GL_COMPRESSED_RGBA', 'GL_TEXTURE_COMPRESSION_HINT',
'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 'GL_TEXTURE_COMPRESSED',
'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 'GL_COMPRESSED_TEXTURE_FORMATS',
'GL_DOT3_RGB', 'GL_DOT3_RGBA', 'GL_CLAMP_TO_BORDER', 'GL_MULTISAMPLE',
'GL_SAMPLE_ALPHA_TO_COVERAGE', 'GL_SAMPLE_ALPHA_TO_ONE', 'GL_SAMPLE_COVERAGE',
'GL_SAMPLE_BUFFERS', 'GL_SAMPLES', 'GL_SAMPLE_COVERAGE_VALUE',
'GL_SAMPLE_COVERAGE_INVERT', 'GL_MULTISAMPLE_BIT', 'GL_VERTEX_ARRAY_EXT',
'GL_NORMAL_ARRAY_EXT', 'GL_COLOR_ARRAY_EXT', 'GL_INDEX_ARRAY_EXT',
'GL_TEXTURE_COORD_ARRAY_EXT', 'GL_EDGE_FLAG_ARRAY_EXT',
'GL_VERTEX_ARRAY_SIZE_EXT', 'GL_VERTEX_ARRAY_TYPE_EXT',
'GL_VERTEX_ARRAY_STRIDE_EXT', 'GL_VERTEX_ARRAY_COUNT_EXT',
'GL_NORMAL_ARRAY_TYPE_EXT', 'GL_NORMAL_ARRAY_STRIDE_EXT',
'GL_NORMAL_ARRAY_COUNT_EXT', 'GL_COLOR_ARRAY_SIZE_EXT',
'GL_COLOR_ARRAY_TYPE_EXT', 'GL_COLOR_ARRAY_STRIDE_EXT',
'GL_COLOR_ARRAY_COUNT_EXT', 'GL_INDEX_ARRAY_TYPE_EXT',
'GL_INDEX_ARRAY_STRIDE_EXT', 'GL_INDEX_ARRAY_COUNT_EXT',
'GL_TEXTURE_COORD_ARRAY_SIZE_EXT', 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT',
'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT', 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT',
'GL_EDGE_FLAG_ARRAY_STRIDE_EXT', 'GL_EDGE_FLAG_ARRAY_COUNT_EXT',
'GL_VERTEX_ARRAY_POINTER_EXT', 'GL_NORMAL_ARRAY_POINTER_EXT',
'GL_COLOR_ARRAY_POINTER_EXT', 'GL_INDEX_ARRAY_POINTER_EXT',
'GL_TEXTURE_COORD_ARRAY_POINTER_EXT', 'GL_EDGE_FLAG_ARRAY_POINTER_EXT',
'GL_TEXTURE_MIN_LOD_SGIS', 'GL_TEXTURE_MAX_LOD_SGIS',
'GL_TEXTURE_BASE_LEVEL_SGIS', 'GL_TEXTURE_MAX_LEVEL_SGIS',
'GL_SHARED_TEXTURE_PALETTE_EXT', 'GL_RESCALE_NORMAL_EXT',
'GL_TEXTURE_COMPARE_SGIX', 'GL_TEXTURE_COMPARE_OPERATOR_SGIX',
'GL_TEXTURE_LEQUAL_R_SGIX', 'GL_TEXTURE_GEQUAL_R_SGIX',
'GL_DEPTH_COMPONENT16_SGIX', 'GL_DEPTH_COMPONENT24_SGIX',
'GL_DEPTH_COMPONENT32_SGIX', 'GL_GENERATE_MIPMAP_SGIS',
'GL_GENERATE_MIPMAP_HINT_SGIS', 'GL_POINT_SIZE_MIN', 'GL_POINT_SIZE_MAX',
'GL_POINT_FADE_THRESHOLD_SIZE', 'GL_POINT_DISTANCE_ATTENUATION',
'GL_FOG_COORDINATE_SOURCE', 'GL_FOG_COORDINATE', 'GL_FRAGMENT_DEPTH',
'GL_CURRENT_FOG_COORDINATE', 'GL_FOG_COORDINATE_ARRAY_TYPE',
'GL_FOG_COORDINATE_ARRAY_STRIDE', 'GL_FOG_COORDINATE_ARRAY_POINTER',
'GL_FOG_COORDINATE_ARRAY', 'GL_COLOR_SUM', 'GL_CURRENT_SECONDARY_COLOR',
'GL_SECONDARY_COLOR_ARRAY_SIZE', 'GL_SECONDARY_COLOR_ARRAY_TYPE',
'GL_SECONDARY_COLOR_ARRAY_STRIDE', 'GL_SECONDARY_COLOR_ARRAY_POINTER',
'GL_SECONDARY_COLOR_ARRAY', 'GL_INCR_WRAP', 'GL_DECR_WRAP',
'GL_MAX_TEXTURE_LOD_BIAS', 'GL_TEXTURE_FILTER_CONTROL', 'GL_TEXTURE_LOD_BIAS',
'GL_GENERATE_MIPMAP', 'GL_GENERATE_MIPMAP_HINT', 'GL_BLEND_DST_RGB',
'GL_BLEND_SRC_RGB', 'GL_BLEND_DST_ALPHA', 'GL_BLEND_SRC_ALPHA',
'GL_MIRRORED_REPEAT', 'GL_DEPTH_COMPONENT16', 'GL_DEPTH_COMPONENT24',
'GL_DEPTH_COMPONENT32', 'GL_TEXTURE_DEPTH_SIZE', 'GL_DEPTH_TEXTURE_MODE',
'GL_TEXTURE_COMPARE_MODE', 'GL_TEXTURE_COMPARE_FUNC',
'GL_COMPARE_R_TO_TEXTURE', 'glAccum', 'glAlphaFunc', 'glAreTexturesResident',
'glArrayElement', 'glBegin', 'glBindTexture', 'glBitmap', 'glBlendFunc',
'glCallList', 'glCallLists', 'glClear', 'glClearAccum', 'glClearColor',
'glClearDepth', 'glClearIndex', 'glClearStencil', 'glClipPlane', 'glColor3b',
'glColor3bv', 'glColor3d', 'glColor3dv', 'glColor3f', 'glColor3fv',
'glColor3i', 'glColor3iv', 'glColor3s', 'glColor3sv', 'glColor3ub',
'glColor3ubv', 'glColor3ui', 'glColor3uiv', 'glColor3us', 'glColor3usv',
'glColor4b', 'glColor4bv', 'glColor4d', 'glColor4dv', 'glColor4f',
'glColor4fv', 'glColor4i', 'glColor4iv', 'glColor4s', 'glColor4sv',
'glColor4ub', 'glColor4ubv', 'glColor4ui', 'glColor4uiv', 'glColor4us',
'glColor4usv', 'glColorMask', 'glColorMaterial', 'glColorPointer',
'glCopyPixels', 'glCopyTexImage1D', 'glCopyTexImage2D', 'glCopyTexSubImage1D',
'glCopyTexSubImage2D', 'glCullFace', 'glDeleteLists', 'glDeleteTextures',
'glDepthFunc', 'glDepthMask', 'glDepthRange', 'glDisable',
'glDisableClientState', 'glDrawArrays', 'glDrawBuffer', 'glDrawElements',
'glDrawPixels', 'glEdgeFlag', 'glEdgeFlagPointer', 'glEdgeFlagv', 'glEnable',
'glEnableClientState', 'glEnd', 'glEndList', 'glEvalCoord1d',
'glEvalCoord1dv', 'glEvalCoord1f', 'glEvalCoord1fv', 'glEvalCoord2d',
'glEvalCoord2dv', 'glEvalCoord2f', 'glEvalCoord2fv', 'glEvalMesh1',
'glEvalMesh2', 'glEvalPoint1', 'glEvalPoint2', 'glFeedbackBuffer', 'glFinish',
'glFlush', 'glFogf', 'glFogfv', 'glFogi', 'glFogiv', 'glFrontFace',
'glFrustum', 'glGenLists', 'glGenTextures', 'glGetBooleanv', 'glGetClipPlane',
'glGetDoublev', 'glGetError', 'glGetFloatv', 'glGetIntegerv', 'glGetLightfv',
'glGetLightiv', 'glGetMapdv', 'glGetMapfv', 'glGetMapiv', 'glGetMaterialfv',
'glGetMaterialiv', 'glGetPixelMapfv', 'glGetPixelMapuiv', 'glGetPixelMapusv',
'glGetPointerv', 'glGetPolygonStipple', 'glGetString', 'glGetTexEnvfv',
'glGetTexEnviv', 'glGetTexGendv', 'glGetTexGenfv', 'glGetTexGeniv',
'glGetTexImage', 'glGetTexLevelParameterfv', 'glGetTexLevelParameteriv',
'glGetTexParameterfv', 'glGetTexParameteriv', 'glHint', 'glIndexMask',
'glIndexPointer', 'glIndexd', 'glIndexdv', 'glIndexf', 'glIndexfv',
'glIndexi', 'glIndexiv', 'glIndexs', 'glIndexsv', 'glIndexub', 'glIndexubv',
'glInitNames', 'glInterleavedArrays', 'glIsEnabled', 'glIsList',
'glIsTexture', 'glLightModelf', 'glLightModelfv', 'glLightModeli',
'glLightModeliv', 'glLightf', 'glLightfv', 'glLighti', 'glLightiv',
'glLineStipple', 'glLineWidth', 'glListBase', 'glLoadIdentity',
'glLoadMatrixd', 'glLoadMatrixf', 'glLoadName', 'glLogicOp', 'glMap1d',
'glMap1f', 'glMap2d', 'glMap2f', 'glMapGrid1d', 'glMapGrid1f', 'glMapGrid2d',
'glMapGrid2f', 'glMaterialf', 'glMaterialfv', 'glMateriali', 'glMaterialiv',
'glMatrixMode', 'glMultMatrixd', 'glMultMatrixf', 'glNewList', 'glNormal3b',
'glNormal3bv', 'glNormal3d', 'glNormal3dv', 'glNormal3f', 'glNormal3fv',
'glNormal3i', 'glNormal3iv', 'glNormal3s', 'glNormal3sv', 'glNormalPointer',
'glOrtho', 'glPassThrough', 'glPixelMapfv', 'glPixelMapuiv', 'glPixelMapusv',
'glPixelStoref', 'glPixelStorei', 'glPixelTransferf', 'glPixelTransferi',
'glPixelZoom', 'glPointSize', 'glPolygonMode', 'glPolygonOffset',
'glPolygonStipple', 'glPopAttrib', 'glPopClientAttrib', 'glPopMatrix',
'glPopName', 'glPrioritizeTextures', 'glPushAttrib', 'glPushClientAttrib',
'glPushMatrix', 'glPushName', 'glRasterPos2d', 'glRasterPos2dv',
'glRasterPos2f', 'glRasterPos2fv', 'glRasterPos2i', 'glRasterPos2iv',
'glRasterPos2s', 'glRasterPos2sv', 'glRasterPos3d', 'glRasterPos3dv',
'glRasterPos3f', 'glRasterPos3fv', 'glRasterPos3i', 'glRasterPos3iv',
'glRasterPos3s', 'glRasterPos3sv', 'glRasterPos4d', 'glRasterPos4dv',
'glRasterPos4f', 'glRasterPos4fv', 'glRasterPos4i', 'glRasterPos4iv',
'glRasterPos4s', 'glRasterPos4sv', 'glReadBuffer', 'glReadPixels', 'glRectd',
'glRectdv', 'glRectf', 'glRectfv', 'glRecti', 'glRectiv', 'glRects',
'glRectsv', 'glRenderMode', 'glRotated', 'glRotatef', 'glScaled', 'glScalef',
'glScissor', 'glSelectBuffer', 'glShadeModel', 'glStencilFunc',
'glStencilMask', 'glStencilOp', 'glTexCoord1d', 'glTexCoord1dv',
'glTexCoord1f', 'glTexCoord1fv', 'glTexCoord1i', 'glTexCoord1iv',
'glTexCoord1s', 'glTexCoord1sv', 'glTexCoord2d', 'glTexCoord2dv',
'glTexCoord2f', 'glTexCoord2fv', 'glTexCoord2i', 'glTexCoord2iv',
'glTexCoord2s', 'glTexCoord2sv', 'glTexCoord3d', 'glTexCoord3dv',
'glTexCoord3f', 'glTexCoord3fv', 'glTexCoord3i', 'glTexCoord3iv',
'glTexCoord3s', 'glTexCoord3sv', 'glTexCoord4d', 'glTexCoord4dv',
'glTexCoord4f', 'glTexCoord4fv', 'glTexCoord4i', 'glTexCoord4iv',
'glTexCoord4s', 'glTexCoord4sv', 'glTexCoordPointer', 'glTexEnvf',
'glTexEnvfv', 'glTexEnvi', 'glTexEnviv', 'glTexGend', 'glTexGendv',
'glTexGenf', 'glTexGenfv', 'glTexGeni', 'glTexGeniv', 'glTexImage1D',
'glTexImage2D', 'glTexParameterf', 'glTexParameterfv', 'glTexParameteri',
'glTexParameteriv', 'glTexSubImage1D', 'glTexSubImage2D', 'glTranslated',
'glTranslatef', 'glVertex2d', 'glVertex2dv', 'glVertex2f', 'glVertex2fv',
'glVertex2i', 'glVertex2iv', 'glVertex2s', 'glVertex2sv', 'glVertex3d',
'glVertex3dv', 'glVertex3f', 'glVertex3fv', 'glVertex3i', 'glVertex3iv',
'glVertex3s', 'glVertex3sv', 'glVertex4d', 'glVertex4dv', 'glVertex4f',
'glVertex4fv', 'glVertex4i', 'glVertex4iv', 'glVertex4s', 'glVertex4sv',
'glVertexPointer', 'glViewport']
# END GENERATED CONTENT (do not edit above this line)




